diff --git a/app/test-pmd/config.c b/app/test-pmd/config.c
index 3ae3e1cd8..392f0c57f 100644
--- a/app/test-pmd/config.c
+++ b/app/test-pmd/config.c
@@ -1639,8 +1639,8 @@ rxtx_config_display(void)
 		printf("  packet len=%u - nb packet segments=%d\n",
 				(unsigned)tx_pkt_length, (int) tx_pkt_nb_segs);
 
-	struct rte_eth_rxconf *rx_conf = &ports[0].rx_conf;
-	struct rte_eth_txconf *tx_conf = &ports[0].tx_conf;
+	struct rte_eth_rxq_conf *rx_conf = &ports[0].rx_conf;
+	struct rte_eth_txq_conf *tx_conf = &ports[0].tx_conf;
 
 	printf("  nb forwarding cores=%d - nb forwarding ports=%d\n",
 	       nb_fwd_lcores, nb_fwd_ports);
diff --git a/app/test-pmd/testpmd.h b/app/test-pmd/testpmd.h
index c9d7739b8..507974f43 100644
--- a/app/test-pmd/testpmd.h
+++ b/app/test-pmd/testpmd.h
@@ -189,8 +189,8 @@ struct rte_port {
 	uint8_t                 need_reconfig_queues; /**< need reconfiguring queues or not */
 	uint8_t                 rss_flag;   /**< enable rss or not */
 	uint8_t                 dcb_flag;   /**< enable dcb */
-	struct rte_eth_rxconf   rx_conf;    /**< rx configuration */
-	struct rte_eth_txconf   tx_conf;    /**< tx configuration */
+	struct rte_eth_rxq_conf   rx_conf;    /**< rx configuration */
+	struct rte_eth_txq_conf   tx_conf;    /**< tx configuration */
 	struct ether_addr       *mc_addr_pool; /**< pool of multicast addrs */
 	uint32_t                mc_addr_nb; /**< nb. of addr. in mc_addr_pool */
 	uint8_t                 slave_flag; /**< bonding slave port */
diff --git a/drivers/net/af_packet/rte_eth_af_packet.c b/drivers/net/af_packet/rte_eth_af_packet.c
index 9a47852ca..7cba0aa91 100644
--- a/drivers/net/af_packet/rte_eth_af_packet.c
+++ b/drivers/net/af_packet/rte_eth_af_packet.c
@@ -395,7 +395,7 @@ eth_rx_queue_setup(struct rte_eth_dev *dev,
                    uint16_t rx_queue_id,
                    uint16_t nb_rx_desc __rte_unused,
                    unsigned int socket_id __rte_unused,
-                   const struct rte_eth_rxconf *rx_conf __rte_unused,
+		   const struct rte_eth_rxq_conf *rx_conf __rte_unused,
                    struct rte_mempool *mb_pool)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
@@ -428,7 +428,7 @@ eth_tx_queue_setup(struct rte_eth_dev *dev,
                    uint16_t tx_queue_id,
                    uint16_t nb_tx_desc __rte_unused,
                    unsigned int socket_id __rte_unused,
-                   const struct rte_eth_txconf *tx_conf __rte_unused)
+		   const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 
 	struct pmd_internals *internals = dev->data->dev_private;
diff --git a/drivers/net/ark/ark_ethdev_rx.c b/drivers/net/ark/ark_ethdev_rx.c
index f5d812a55..eb5a2c70a 100644
--- a/drivers/net/ark/ark_ethdev_rx.c
+++ b/drivers/net/ark/ark_ethdev_rx.c
@@ -140,7 +140,7 @@ eth_ark_dev_rx_queue_setup(struct rte_eth_dev *dev,
 			   uint16_t queue_idx,
 			   uint16_t nb_desc,
 			   unsigned int socket_id,
-			   const struct rte_eth_rxconf *rx_conf,
+			   const struct rte_eth_rxq_conf *rx_conf,
 			   struct rte_mempool *mb_pool)
 {
 	static int warning1;		/* = 0 */
@@ -163,7 +163,7 @@ eth_ark_dev_rx_queue_setup(struct rte_eth_dev *dev,
 	if (rx_conf != NULL && warning1 == 0) {
 		warning1 = 1;
 		PMD_DRV_LOG(INFO,
-			    "Arkville ignores rte_eth_rxconf argument.\n");
+			    "Arkville ignores rte_eth_rxq_conf argument.\n");
 	}
 
 	if (RTE_PKTMBUF_HEADROOM < ARK_RX_META_SIZE) {
diff --git a/drivers/net/ark/ark_ethdev_rx.h b/drivers/net/ark/ark_ethdev_rx.h
index 3a54a4c91..15b494243 100644
--- a/drivers/net/ark/ark_ethdev_rx.h
+++ b/drivers/net/ark/ark_ethdev_rx.h
@@ -45,7 +45,7 @@ int eth_ark_dev_rx_queue_setup(struct rte_eth_dev *dev,
 			       uint16_t queue_idx,
 			       uint16_t nb_desc,
 			       unsigned int socket_id,
-			       const struct rte_eth_rxconf *rx_conf,
+			       const struct rte_eth_rxq_conf *rx_conf,
 			       struct rte_mempool *mp);
 uint32_t eth_ark_dev_rx_queue_count(struct rte_eth_dev *dev,
 				    uint16_t rx_queue_id);
diff --git a/drivers/net/ark/ark_ethdev_tx.c b/drivers/net/ark/ark_ethdev_tx.c
index 0e2d60deb..0e8aaf47a 100644
--- a/drivers/net/ark/ark_ethdev_tx.c
+++ b/drivers/net/ark/ark_ethdev_tx.c
@@ -234,7 +234,7 @@ eth_ark_tx_queue_setup(struct rte_eth_dev *dev,
 		       uint16_t queue_idx,
 		       uint16_t nb_desc,
 		       unsigned int socket_id,
-		       const struct rte_eth_txconf *tx_conf __rte_unused)
+		       const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct ark_adapter *ark = (struct ark_adapter *)dev->data->dev_private;
 	struct ark_tx_queue *queue;
diff --git a/drivers/net/ark/ark_ethdev_tx.h b/drivers/net/ark/ark_ethdev_tx.h
index 8aaafc22e..eb7ab63ed 100644
--- a/drivers/net/ark/ark_ethdev_tx.h
+++ b/drivers/net/ark/ark_ethdev_tx.h
@@ -49,7 +49,7 @@ int eth_ark_tx_queue_setup(struct rte_eth_dev *dev,
 			   uint16_t queue_idx,
 			   uint16_t nb_desc,
 			   unsigned int socket_id,
-			   const struct rte_eth_txconf *tx_conf);
+			   const struct rte_eth_txq_conf *tx_conf);
 void eth_ark_tx_queue_release(void *vtx_queue);
 int eth_ark_tx_queue_stop(struct rte_eth_dev *dev, uint16_t queue_id);
 int eth_ark_tx_queue_start(struct rte_eth_dev *dev, uint16_t queue_id);
diff --git a/drivers/net/avp/avp_ethdev.c b/drivers/net/avp/avp_ethdev.c
index c746a0e2c..01bc08a7d 100644
--- a/drivers/net/avp/avp_ethdev.c
+++ b/drivers/net/avp/avp_ethdev.c
@@ -79,14 +79,14 @@ static int avp_dev_rx_queue_setup(struct rte_eth_dev *dev,
 				  uint16_t rx_queue_id,
 				  uint16_t nb_rx_desc,
 				  unsigned int socket_id,
-				  const struct rte_eth_rxconf *rx_conf,
+				  const struct rte_eth_rxq_conf *rx_conf,
 				  struct rte_mempool *pool);
 
 static int avp_dev_tx_queue_setup(struct rte_eth_dev *dev,
 				  uint16_t tx_queue_id,
 				  uint16_t nb_tx_desc,
 				  unsigned int socket_id,
-				  const struct rte_eth_txconf *tx_conf);
+				  const struct rte_eth_txq_conf *tx_conf);
 
 static uint16_t avp_recv_scattered_pkts(void *rx_queue,
 					struct rte_mbuf **rx_pkts,
@@ -1143,7 +1143,7 @@ avp_dev_rx_queue_setup(struct rte_eth_dev *eth_dev,
 		       uint16_t rx_queue_id,
 		       uint16_t nb_rx_desc,
 		       unsigned int socket_id,
-		       const struct rte_eth_rxconf *rx_conf,
+		       const struct rte_eth_rxq_conf *rx_conf,
 		       struct rte_mempool *pool)
 {
 	struct avp_dev *avp = AVP_DEV_PRIVATE_TO_HW(eth_dev->data->dev_private);
@@ -1207,7 +1207,7 @@ avp_dev_tx_queue_setup(struct rte_eth_dev *eth_dev,
 		       uint16_t tx_queue_id,
 		       uint16_t nb_tx_desc,
 		       unsigned int socket_id,
-		       const struct rte_eth_txconf *tx_conf)
+		       const struct rte_eth_txq_conf *tx_conf)
 {
 	struct avp_dev *avp = AVP_DEV_PRIVATE_TO_HW(eth_dev->data->dev_private);
 	struct avp_queue *txq;
diff --git a/drivers/net/bnx2x/bnx2x_rxtx.c b/drivers/net/bnx2x/bnx2x_rxtx.c
index 5dd4aee7f..1a0c633b1 100644
--- a/drivers/net/bnx2x/bnx2x_rxtx.c
+++ b/drivers/net/bnx2x/bnx2x_rxtx.c
@@ -60,7 +60,7 @@ bnx2x_dev_rx_queue_setup(struct rte_eth_dev *dev,
 		       uint16_t queue_idx,
 		       uint16_t nb_desc,
 		       unsigned int socket_id,
-		       __rte_unused const struct rte_eth_rxconf *rx_conf,
+		       __rte_unused const struct rte_eth_rxq_conf *rx_conf,
 		       struct rte_mempool *mp)
 {
 	uint16_t j, idx;
@@ -246,7 +246,7 @@ bnx2x_dev_tx_queue_setup(struct rte_eth_dev *dev,
 		       uint16_t queue_idx,
 		       uint16_t nb_desc,
 		       unsigned int socket_id,
-		       const struct rte_eth_txconf *tx_conf)
+		       const struct rte_eth_txq_conf *tx_conf)
 {
 	uint16_t i;
 	unsigned int tsize;
diff --git a/drivers/net/bnx2x/bnx2x_rxtx.h b/drivers/net/bnx2x/bnx2x_rxtx.h
index 2e38ec26a..1c6a6b38d 100644
--- a/drivers/net/bnx2x/bnx2x_rxtx.h
+++ b/drivers/net/bnx2x/bnx2x_rxtx.h
@@ -68,12 +68,12 @@ struct bnx2x_tx_queue {
 
 int bnx2x_dev_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 			      uint16_t nb_rx_desc, unsigned int socket_id,
-			      const struct rte_eth_rxconf *rx_conf,
+			      const struct rte_eth_rxq_conf *rx_conf,
 			      struct rte_mempool *mb_pool);
 
 int bnx2x_dev_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
 			      uint16_t nb_tx_desc, unsigned int socket_id,
-			      const struct rte_eth_txconf *tx_conf);
+			      const struct rte_eth_txq_conf *tx_conf);
 
 void bnx2x_dev_rx_queue_release(void *rxq);
 void bnx2x_dev_tx_queue_release(void *txq);
diff --git a/drivers/net/bnxt/bnxt_ethdev.c b/drivers/net/bnxt/bnxt_ethdev.c
index c9d11228b..508e6b752 100644
--- a/drivers/net/bnxt/bnxt_ethdev.c
+++ b/drivers/net/bnxt/bnxt_ethdev.c
@@ -391,7 +391,7 @@ static void bnxt_dev_info_get_op(struct rte_eth_dev *eth_dev,
 					DEV_TX_OFFLOAD_GENEVE_TNL_TSO;
 
 	/* *INDENT-OFF* */
-	dev_info->default_rxconf = (struct rte_eth_rxconf) {
+	dev_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_thresh = {
 			.pthresh = 8,
 			.hthresh = 8,
@@ -401,7 +401,7 @@ static void bnxt_dev_info_get_op(struct rte_eth_dev *eth_dev,
 		.rx_drop_en = 0,
 	};
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.tx_thresh = {
 			.pthresh = 32,
 			.hthresh = 0,
diff --git a/drivers/net/bnxt/bnxt_rxq.c b/drivers/net/bnxt/bnxt_rxq.c
index 0793820b1..d0ab47c36 100644
--- a/drivers/net/bnxt/bnxt_rxq.c
+++ b/drivers/net/bnxt/bnxt_rxq.c
@@ -293,7 +293,7 @@ int bnxt_rx_queue_setup_op(struct rte_eth_dev *eth_dev,
 			       uint16_t queue_idx,
 			       uint16_t nb_desc,
 			       unsigned int socket_id,
-			       const struct rte_eth_rxconf *rx_conf,
+			       const struct rte_eth_rxq_conf *rx_conf,
 			       struct rte_mempool *mp)
 {
 	struct bnxt *bp = (struct bnxt *)eth_dev->data->dev_private;
diff --git a/drivers/net/bnxt/bnxt_rxq.h b/drivers/net/bnxt/bnxt_rxq.h
index 01aaa007f..29c0aa0a5 100644
--- a/drivers/net/bnxt/bnxt_rxq.h
+++ b/drivers/net/bnxt/bnxt_rxq.h
@@ -70,7 +70,7 @@ int bnxt_rx_queue_setup_op(struct rte_eth_dev *eth_dev,
 			       uint16_t queue_idx,
 			       uint16_t nb_desc,
 			       unsigned int socket_id,
-			       const struct rte_eth_rxconf *rx_conf,
+			       const struct rte_eth_rxq_conf *rx_conf,
 			       struct rte_mempool *mp);
 void bnxt_free_rx_mbufs(struct bnxt *bp);
 
diff --git a/drivers/net/bnxt/bnxt_txq.c b/drivers/net/bnxt/bnxt_txq.c
index 99dddddfc..f4701bd68 100644
--- a/drivers/net/bnxt/bnxt_txq.c
+++ b/drivers/net/bnxt/bnxt_txq.c
@@ -102,7 +102,7 @@ int bnxt_tx_queue_setup_op(struct rte_eth_dev *eth_dev,
 			       uint16_t queue_idx,
 			       uint16_t nb_desc,
 			       unsigned int socket_id,
-			       const struct rte_eth_txconf *tx_conf)
+			       const struct rte_eth_txq_conf *tx_conf)
 {
 	struct bnxt *bp = (struct bnxt *)eth_dev->data->dev_private;
 	struct bnxt_tx_queue *txq;
diff --git a/drivers/net/bnxt/bnxt_txq.h b/drivers/net/bnxt/bnxt_txq.h
index 16f3a0bdd..5071dfd5b 100644
--- a/drivers/net/bnxt/bnxt_txq.h
+++ b/drivers/net/bnxt/bnxt_txq.h
@@ -70,6 +70,6 @@ int bnxt_tx_queue_setup_op(struct rte_eth_dev *eth_dev,
 			       uint16_t queue_idx,
 			       uint16_t nb_desc,
 			       unsigned int socket_id,
-			       const struct rte_eth_txconf *tx_conf);
+			       const struct rte_eth_txq_conf *tx_conf);
 
 #endif
diff --git a/drivers/net/bonding/rte_eth_bond_pmd.c b/drivers/net/bonding/rte_eth_bond_pmd.c
index 3ee70baa0..fbf7ffba5 100644
--- a/drivers/net/bonding/rte_eth_bond_pmd.c
+++ b/drivers/net/bonding/rte_eth_bond_pmd.c
@@ -2153,7 +2153,8 @@ bond_ethdev_vlan_filter_set(struct rte_eth_dev *dev, uint16_t vlan_id, int on)
 static int
 bond_ethdev_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 		uint16_t nb_rx_desc, unsigned int socket_id __rte_unused,
-		const struct rte_eth_rxconf *rx_conf, struct rte_mempool *mb_pool)
+		const struct rte_eth_rxq_conf *rx_conf,
+		struct rte_mempool *mb_pool)
 {
 	struct bond_rx_queue *bd_rx_q = (struct bond_rx_queue *)
 			rte_zmalloc_socket(NULL, sizeof(struct bond_rx_queue),
@@ -2166,7 +2167,7 @@ bond_ethdev_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 
 	bd_rx_q->nb_rx_desc = nb_rx_desc;
 
-	memcpy(&(bd_rx_q->rx_conf), rx_conf, sizeof(struct rte_eth_rxconf));
+	memcpy(&(bd_rx_q->rx_conf), rx_conf, sizeof(struct rte_eth_rxq_conf));
 	bd_rx_q->mb_pool = mb_pool;
 
 	dev->data->rx_queues[rx_queue_id] = bd_rx_q;
@@ -2177,7 +2178,7 @@ bond_ethdev_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 static int
 bond_ethdev_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
 		uint16_t nb_tx_desc, unsigned int socket_id __rte_unused,
-		const struct rte_eth_txconf *tx_conf)
+		const struct rte_eth_txq_conf *tx_conf)
 {
 	struct bond_tx_queue *bd_tx_q  = (struct bond_tx_queue *)
 			rte_zmalloc_socket(NULL, sizeof(struct bond_tx_queue),
diff --git a/drivers/net/bonding/rte_eth_bond_private.h b/drivers/net/bonding/rte_eth_bond_private.h
index 1fe6ff880..579a18c98 100644
--- a/drivers/net/bonding/rte_eth_bond_private.h
+++ b/drivers/net/bonding/rte_eth_bond_private.h
@@ -74,7 +74,7 @@ struct bond_rx_queue {
 	/**< Reference to eth_dev private structure */
 	uint16_t nb_rx_desc;
 	/**< Number of RX descriptors available for the queue */
-	struct rte_eth_rxconf rx_conf;
+	struct rte_eth_rxq_conf rx_conf;
 	/**< Copy of RX configuration structure for queue */
 	struct rte_mempool *mb_pool;
 	/**< Reference to mbuf pool to use for RX queue */
@@ -87,7 +87,7 @@ struct bond_tx_queue {
 	/**< Reference to dev private structure */
 	uint16_t nb_tx_desc;
 	/**< Number of TX descriptors available for the queue */
-	struct rte_eth_txconf tx_conf;
+	struct rte_eth_txq_conf tx_conf;
 	/**< Copy of TX configuration structure for queue */
 };
 
diff --git a/drivers/net/cxgbe/cxgbe_ethdev.c b/drivers/net/cxgbe/cxgbe_ethdev.c
index 7bca45614..b8f965765 100644
--- a/drivers/net/cxgbe/cxgbe_ethdev.c
+++ b/drivers/net/cxgbe/cxgbe_ethdev.c
@@ -443,7 +443,7 @@ static int cxgbe_dev_tx_queue_stop(struct rte_eth_dev *eth_dev,
 static int cxgbe_dev_tx_queue_setup(struct rte_eth_dev *eth_dev,
 				    uint16_t queue_idx,	uint16_t nb_desc,
 				    unsigned int socket_id,
-				    const struct rte_eth_txconf *tx_conf)
+				    const struct rte_eth_txq_conf *tx_conf)
 {
 	struct port_info *pi = (struct port_info *)(eth_dev->data->dev_private);
 	struct adapter *adapter = pi->adapter;
@@ -552,7 +552,7 @@ static int cxgbe_dev_rx_queue_stop(struct rte_eth_dev *eth_dev,
 static int cxgbe_dev_rx_queue_setup(struct rte_eth_dev *eth_dev,
 				    uint16_t queue_idx,	uint16_t nb_desc,
 				    unsigned int socket_id,
-				    const struct rte_eth_rxconf *rx_conf,
+				    const struct rte_eth_rxq_conf *rx_conf,
 				    struct rte_mempool *mp)
 {
 	struct port_info *pi = (struct port_info *)(eth_dev->data->dev_private);
diff --git a/drivers/net/dpaa2/dpaa2_ethdev.c b/drivers/net/dpaa2/dpaa2_ethdev.c
index 429b3a086..80b79ecc2 100644
--- a/drivers/net/dpaa2/dpaa2_ethdev.c
+++ b/drivers/net/dpaa2/dpaa2_ethdev.c
@@ -355,7 +355,7 @@ dpaa2_dev_rx_queue_setup(struct rte_eth_dev *dev,
 			 uint16_t rx_queue_id,
 			 uint16_t nb_rx_desc __rte_unused,
 			 unsigned int socket_id __rte_unused,
-			 const struct rte_eth_rxconf *rx_conf __rte_unused,
+			 const struct rte_eth_rxq_conf *rx_conf __rte_unused,
 			 struct rte_mempool *mb_pool)
 {
 	struct dpaa2_dev_priv *priv = dev->data->dev_private;
@@ -440,7 +440,7 @@ dpaa2_dev_tx_queue_setup(struct rte_eth_dev *dev,
 			 uint16_t tx_queue_id,
 			 uint16_t nb_tx_desc __rte_unused,
 			 unsigned int socket_id __rte_unused,
-			 const struct rte_eth_txconf *tx_conf __rte_unused)
+			 const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct dpaa2_dev_priv *priv = dev->data->dev_private;
 	struct dpaa2_queue *dpaa2_q = (struct dpaa2_queue *)
diff --git a/drivers/net/e1000/e1000_ethdev.h b/drivers/net/e1000/e1000_ethdev.h
index 5668910c5..6390cc137 100644
--- a/drivers/net/e1000/e1000_ethdev.h
+++ b/drivers/net/e1000/e1000_ethdev.h
@@ -372,7 +372,7 @@ void igb_dev_free_queues(struct rte_eth_dev *dev);
 
 int eth_igb_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 		uint16_t nb_rx_desc, unsigned int socket_id,
-		const struct rte_eth_rxconf *rx_conf,
+		const struct rte_eth_rxq_conf *rx_conf,
 		struct rte_mempool *mb_pool);
 
 uint32_t eth_igb_rx_queue_count(struct rte_eth_dev *dev,
@@ -385,7 +385,7 @@ int eth_igb_tx_descriptor_status(void *tx_queue, uint16_t offset);
 
 int eth_igb_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
 		uint16_t nb_tx_desc, unsigned int socket_id,
-		const struct rte_eth_txconf *tx_conf);
+		const struct rte_eth_txq_conf *tx_conf);
 
 int eth_igb_tx_done_cleanup(void *txq, uint32_t free_cnt);
 
@@ -441,7 +441,7 @@ void em_dev_free_queues(struct rte_eth_dev *dev);
 
 int eth_em_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 		uint16_t nb_rx_desc, unsigned int socket_id,
-		const struct rte_eth_rxconf *rx_conf,
+		const struct rte_eth_rxq_conf *rx_conf,
 		struct rte_mempool *mb_pool);
 
 uint32_t eth_em_rx_queue_count(struct rte_eth_dev *dev,
@@ -454,7 +454,7 @@ int eth_em_tx_descriptor_status(void *tx_queue, uint16_t offset);
 
 int eth_em_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
 		uint16_t nb_tx_desc, unsigned int socket_id,
-		const struct rte_eth_txconf *tx_conf);
+		const struct rte_eth_txq_conf *tx_conf);
 
 int eth_em_rx_init(struct rte_eth_dev *dev);
 
diff --git a/drivers/net/e1000/em_rxtx.c b/drivers/net/e1000/em_rxtx.c
index 31819c5bd..857b7167d 100644
--- a/drivers/net/e1000/em_rxtx.c
+++ b/drivers/net/e1000/em_rxtx.c
@@ -1185,7 +1185,7 @@ eth_em_tx_queue_setup(struct rte_eth_dev *dev,
 			 uint16_t queue_idx,
 			 uint16_t nb_desc,
 			 unsigned int socket_id,
-			 const struct rte_eth_txconf *tx_conf)
+			 const struct rte_eth_txq_conf *tx_conf)
 {
 	const struct rte_memzone *tz;
 	struct em_tx_queue *txq;
@@ -1347,7 +1347,7 @@ eth_em_rx_queue_setup(struct rte_eth_dev *dev,
 		uint16_t queue_idx,
 		uint16_t nb_desc,
 		unsigned int socket_id,
-		const struct rte_eth_rxconf *rx_conf,
+		const struct rte_eth_rxq_conf *rx_conf,
 		struct rte_mempool *mp)
 {
 	const struct rte_memzone *rz;
diff --git a/drivers/net/e1000/igb_ethdev.c b/drivers/net/e1000/igb_ethdev.c
index e4f7a9faf..7ac3703ac 100644
--- a/drivers/net/e1000/igb_ethdev.c
+++ b/drivers/net/e1000/igb_ethdev.c
@@ -2252,7 +2252,7 @@ eth_igb_infos_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 	dev_info->reta_size = ETH_RSS_RETA_SIZE_128;
 	dev_info->flow_type_rss_offloads = IGB_RSS_OFFLOAD_ALL;
 
-	dev_info->default_rxconf = (struct rte_eth_rxconf) {
+	dev_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_thresh = {
 			.pthresh = IGB_DEFAULT_RX_PTHRESH,
 			.hthresh = IGB_DEFAULT_RX_HTHRESH,
@@ -2262,7 +2262,7 @@ eth_igb_infos_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 		.rx_drop_en = 0,
 	};
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.tx_thresh = {
 			.pthresh = IGB_DEFAULT_TX_PTHRESH,
 			.hthresh = IGB_DEFAULT_TX_HTHRESH,
@@ -2339,7 +2339,7 @@ eth_igbvf_infos_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 		break;
 	}
 
-	dev_info->default_rxconf = (struct rte_eth_rxconf) {
+	dev_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_thresh = {
 			.pthresh = IGB_DEFAULT_RX_PTHRESH,
 			.hthresh = IGB_DEFAULT_RX_HTHRESH,
@@ -2349,7 +2349,7 @@ eth_igbvf_infos_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 		.rx_drop_en = 0,
 	};
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.tx_thresh = {
 			.pthresh = IGB_DEFAULT_TX_PTHRESH,
 			.hthresh = IGB_DEFAULT_TX_HTHRESH,
diff --git a/drivers/net/e1000/igb_rxtx.c b/drivers/net/e1000/igb_rxtx.c
index 1c80a2a1b..f4a7fe571 100644
--- a/drivers/net/e1000/igb_rxtx.c
+++ b/drivers/net/e1000/igb_rxtx.c
@@ -1458,7 +1458,7 @@ eth_igb_tx_queue_setup(struct rte_eth_dev *dev,
 			 uint16_t queue_idx,
 			 uint16_t nb_desc,
 			 unsigned int socket_id,
-			 const struct rte_eth_txconf *tx_conf)
+			 const struct rte_eth_txq_conf *tx_conf)
 {
 	const struct rte_memzone *tz;
 	struct igb_tx_queue *txq;
@@ -1604,7 +1604,7 @@ eth_igb_rx_queue_setup(struct rte_eth_dev *dev,
 			 uint16_t queue_idx,
 			 uint16_t nb_desc,
 			 unsigned int socket_id,
-			 const struct rte_eth_rxconf *rx_conf,
+			 const struct rte_eth_rxq_conf *rx_conf,
 			 struct rte_mempool *mp)
 {
 	const struct rte_memzone *rz;
diff --git a/drivers/net/ena/ena_ethdev.c b/drivers/net/ena/ena_ethdev.c
index 80ce1f353..69fe5218d 100644
--- a/drivers/net/ena/ena_ethdev.c
+++ b/drivers/net/ena/ena_ethdev.c
@@ -193,10 +193,10 @@ static uint16_t eth_ena_prep_pkts(void *tx_queue, struct rte_mbuf **tx_pkts,
 		uint16_t nb_pkts);
 static int ena_tx_queue_setup(struct rte_eth_dev *dev, uint16_t queue_idx,
 			      uint16_t nb_desc, unsigned int socket_id,
-			      const struct rte_eth_txconf *tx_conf);
+			      const struct rte_eth_txq_conf *tx_conf);
 static int ena_rx_queue_setup(struct rte_eth_dev *dev, uint16_t queue_idx,
 			      uint16_t nb_desc, unsigned int socket_id,
-			      const struct rte_eth_rxconf *rx_conf,
+			      const struct rte_eth_rxq_conf *rx_conf,
 			      struct rte_mempool *mp);
 static uint16_t eth_ena_recv_pkts(void *rx_queue,
 				  struct rte_mbuf **rx_pkts, uint16_t nb_pkts);
@@ -940,11 +940,12 @@ static int ena_queue_restart(struct ena_ring *ring)
 	return 0;
 }
 
-static int ena_tx_queue_setup(struct rte_eth_dev *dev,
-			      uint16_t queue_idx,
-			      uint16_t nb_desc,
-			      __rte_unused unsigned int socket_id,
-			      __rte_unused const struct rte_eth_txconf *tx_conf)
+static int ena_tx_queue_setup(
+		struct rte_eth_dev *dev,
+		uint16_t queue_idx,
+		uint16_t nb_desc,
+		__rte_unused unsigned int socket_id,
+		__rte_unused const struct rte_eth_txq_conf *tx_conf)
 {
 	struct ena_com_create_io_ctx ctx =
 		/* policy set to _HOST just to satisfy icc compiler */
@@ -1042,12 +1043,13 @@ static int ena_tx_queue_setup(struct rte_eth_dev *dev,
 	return rc;
 }
 
-static int ena_rx_queue_setup(struct rte_eth_dev *dev,
-			      uint16_t queue_idx,
-			      uint16_t nb_desc,
-			      __rte_unused unsigned int socket_id,
-			      __rte_unused const struct rte_eth_rxconf *rx_conf,
-			      struct rte_mempool *mp)
+static int ena_rx_queue_setup(
+		struct rte_eth_dev *dev,
+		uint16_t queue_idx,
+		uint16_t nb_desc,
+		__rte_unused unsigned int socket_id,
+		__rte_unused const struct rte_eth_rxq_conf *rx_conf,
+		struct rte_mempool *mp)
 {
 	struct ena_com_create_io_ctx ctx =
 		/* policy set to _HOST just to satisfy icc compiler */
diff --git a/drivers/net/enic/enic_ethdev.c b/drivers/net/enic/enic_ethdev.c
index da8fec2d0..da7e88d23 100644
--- a/drivers/net/enic/enic_ethdev.c
+++ b/drivers/net/enic/enic_ethdev.c
@@ -191,7 +191,7 @@ static int enicpmd_dev_tx_queue_setup(struct rte_eth_dev *eth_dev,
 	uint16_t queue_idx,
 	uint16_t nb_desc,
 	unsigned int socket_id,
-	__rte_unused const struct rte_eth_txconf *tx_conf)
+	__rte_unused const struct rte_eth_txq_conf *tx_conf)
 {
 	int ret;
 	struct enic *enic = pmd_priv(eth_dev);
@@ -303,7 +303,7 @@ static int enicpmd_dev_rx_queue_setup(struct rte_eth_dev *eth_dev,
 	uint16_t queue_idx,
 	uint16_t nb_desc,
 	unsigned int socket_id,
-	const struct rte_eth_rxconf *rx_conf,
+	const struct rte_eth_rxq_conf *rx_conf,
 	struct rte_mempool *mp)
 {
 	int ret;
@@ -485,7 +485,7 @@ static void enicpmd_dev_info_get(struct rte_eth_dev *eth_dev,
 		DEV_TX_OFFLOAD_UDP_CKSUM   |
 		DEV_TX_OFFLOAD_TCP_CKSUM   |
 		DEV_TX_OFFLOAD_TCP_TSO;
-	device_info->default_rxconf = (struct rte_eth_rxconf) {
+	device_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_free_thresh = ENIC_DEFAULT_RX_FREE_THRESH
 	};
 }
diff --git a/drivers/net/failsafe/failsafe_ops.c b/drivers/net/failsafe/failsafe_ops.c
index ff9ad155c..6f3f5ef56 100644
--- a/drivers/net/failsafe/failsafe_ops.c
+++ b/drivers/net/failsafe/failsafe_ops.c
@@ -384,7 +384,7 @@ fs_rx_queue_setup(struct rte_eth_dev *dev,
 		uint16_t rx_queue_id,
 		uint16_t nb_rx_desc,
 		unsigned int socket_id,
-		const struct rte_eth_rxconf *rx_conf,
+		const struct rte_eth_rxq_conf *rx_conf,
 		struct rte_mempool *mb_pool)
 {
 	struct sub_device *sdev;
@@ -452,7 +452,7 @@ fs_tx_queue_setup(struct rte_eth_dev *dev,
 		uint16_t tx_queue_id,
 		uint16_t nb_tx_desc,
 		unsigned int socket_id,
-		const struct rte_eth_txconf *tx_conf)
+		const struct rte_eth_txq_conf *tx_conf)
 {
 	struct sub_device *sdev;
 	struct txq *txq;
diff --git a/drivers/net/fm10k/fm10k_ethdev.c b/drivers/net/fm10k/fm10k_ethdev.c
index e60d3a365..d6d9d9169 100644
--- a/drivers/net/fm10k/fm10k_ethdev.c
+++ b/drivers/net/fm10k/fm10k_ethdev.c
@@ -1427,7 +1427,7 @@ fm10k_dev_infos_get(struct rte_eth_dev *dev,
 	dev_info->hash_key_size = FM10K_RSSRK_SIZE * sizeof(uint32_t);
 	dev_info->reta_size = FM10K_MAX_RSS_INDICES;
 
-	dev_info->default_rxconf = (struct rte_eth_rxconf) {
+	dev_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_thresh = {
 			.pthresh = FM10K_DEFAULT_RX_PTHRESH,
 			.hthresh = FM10K_DEFAULT_RX_HTHRESH,
@@ -1437,7 +1437,7 @@ fm10k_dev_infos_get(struct rte_eth_dev *dev,
 		.rx_drop_en = 0,
 	};
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.tx_thresh = {
 			.pthresh = FM10K_DEFAULT_TX_PTHRESH,
 			.hthresh = FM10K_DEFAULT_TX_HTHRESH,
@@ -1740,7 +1740,7 @@ check_thresh(uint16_t min, uint16_t max, uint16_t div, uint16_t request)
 }
 
 static inline int
-handle_rxconf(struct fm10k_rx_queue *q, const struct rte_eth_rxconf *conf)
+handle_rxconf(struct fm10k_rx_queue *q, const struct rte_eth_rxq_conf *conf)
 {
 	uint16_t rx_free_thresh;
 
@@ -1805,7 +1805,7 @@ mempool_element_size_valid(struct rte_mempool *mp)
 static int
 fm10k_rx_queue_setup(struct rte_eth_dev *dev, uint16_t queue_id,
 	uint16_t nb_desc, unsigned int socket_id,
-	const struct rte_eth_rxconf *conf, struct rte_mempool *mp)
+	const struct rte_eth_rxq_conf *conf, struct rte_mempool *mp)
 {
 	struct fm10k_hw *hw = FM10K_DEV_PRIVATE_TO_HW(dev->data->dev_private);
 	struct fm10k_dev_info *dev_info =
@@ -1912,7 +1912,7 @@ fm10k_rx_queue_release(void *queue)
 }
 
 static inline int
-handle_txconf(struct fm10k_tx_queue *q, const struct rte_eth_txconf *conf)
+handle_txconf(struct fm10k_tx_queue *q, const struct rte_eth_txq_conf *conf)
 {
 	uint16_t tx_free_thresh;
 	uint16_t tx_rs_thresh;
@@ -1971,7 +1971,7 @@ handle_txconf(struct fm10k_tx_queue *q, const struct rte_eth_txconf *conf)
 static int
 fm10k_tx_queue_setup(struct rte_eth_dev *dev, uint16_t queue_id,
 	uint16_t nb_desc, unsigned int socket_id,
-	const struct rte_eth_txconf *conf)
+	const struct rte_eth_txq_conf *conf)
 {
 	struct fm10k_hw *hw = FM10K_DEV_PRIVATE_TO_HW(dev->data->dev_private);
 	struct fm10k_tx_queue *q;
diff --git a/drivers/net/i40e/i40e_ethdev.c b/drivers/net/i40e/i40e_ethdev.c
index 8e0580c56..9dc422cbb 100644
--- a/drivers/net/i40e/i40e_ethdev.c
+++ b/drivers/net/i40e/i40e_ethdev.c
@@ -2973,7 +2973,7 @@ i40e_dev_info_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 	dev_info->reta_size = pf->hash_lut_size;
 	dev_info->flow_type_rss_offloads = I40E_RSS_OFFLOAD_ALL;
 
-	dev_info->default_rxconf = (struct rte_eth_rxconf) {
+	dev_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_thresh = {
 			.pthresh = I40E_DEFAULT_RX_PTHRESH,
 			.hthresh = I40E_DEFAULT_RX_HTHRESH,
@@ -2983,7 +2983,7 @@ i40e_dev_info_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 		.rx_drop_en = 0,
 	};
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.tx_thresh = {
 			.pthresh = I40E_DEFAULT_TX_PTHRESH,
 			.hthresh = I40E_DEFAULT_TX_HTHRESH,
diff --git a/drivers/net/i40e/i40e_ethdev_vf.c b/drivers/net/i40e/i40e_ethdev_vf.c
index 7c5c16b85..61938d487 100644
--- a/drivers/net/i40e/i40e_ethdev_vf.c
+++ b/drivers/net/i40e/i40e_ethdev_vf.c
@@ -2144,7 +2144,7 @@ i40evf_dev_info_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 		DEV_TX_OFFLOAD_TCP_CKSUM |
 		DEV_TX_OFFLOAD_SCTP_CKSUM;
 
-	dev_info->default_rxconf = (struct rte_eth_rxconf) {
+	dev_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_thresh = {
 			.pthresh = I40E_DEFAULT_RX_PTHRESH,
 			.hthresh = I40E_DEFAULT_RX_HTHRESH,
@@ -2154,7 +2154,7 @@ i40evf_dev_info_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 		.rx_drop_en = 0,
 	};
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.tx_thresh = {
 			.pthresh = I40E_DEFAULT_TX_PTHRESH,
 			.hthresh = I40E_DEFAULT_TX_HTHRESH,
diff --git a/drivers/net/i40e/i40e_rxtx.c b/drivers/net/i40e/i40e_rxtx.c
index d42c23c05..f4e367db8 100644
--- a/drivers/net/i40e/i40e_rxtx.c
+++ b/drivers/net/i40e/i40e_rxtx.c
@@ -1731,7 +1731,7 @@ i40e_dev_rx_queue_setup(struct rte_eth_dev *dev,
 			uint16_t queue_idx,
 			uint16_t nb_desc,
 			unsigned int socket_id,
-			const struct rte_eth_rxconf *rx_conf,
+			const struct rte_eth_rxq_conf *rx_conf,
 			struct rte_mempool *mp)
 {
 	struct i40e_vsi *vsi;
@@ -2010,7 +2010,7 @@ i40e_dev_tx_queue_setup(struct rte_eth_dev *dev,
 			uint16_t queue_idx,
 			uint16_t nb_desc,
 			unsigned int socket_id,
-			const struct rte_eth_txconf *tx_conf)
+			const struct rte_eth_txq_conf *tx_conf)
 {
 	struct i40e_vsi *vsi;
 	struct i40e_hw *hw = I40E_DEV_PRIVATE_TO_HW(dev->data->dev_private);
diff --git a/drivers/net/i40e/i40e_rxtx.h b/drivers/net/i40e/i40e_rxtx.h
index 20084d649..9d48e33f9 100644
--- a/drivers/net/i40e/i40e_rxtx.h
+++ b/drivers/net/i40e/i40e_rxtx.h
@@ -201,13 +201,13 @@ int i40e_dev_rx_queue_setup(struct rte_eth_dev *dev,
 			    uint16_t queue_idx,
 			    uint16_t nb_desc,
 			    unsigned int socket_id,
-			    const struct rte_eth_rxconf *rx_conf,
+			    const struct rte_eth_rxq_conf *rx_conf,
 			    struct rte_mempool *mp);
 int i40e_dev_tx_queue_setup(struct rte_eth_dev *dev,
 			    uint16_t queue_idx,
 			    uint16_t nb_desc,
 			    unsigned int socket_id,
-			    const struct rte_eth_txconf *tx_conf);
+			    const struct rte_eth_txq_conf *tx_conf);
 void i40e_dev_rx_queue_release(void *rxq);
 void i40e_dev_tx_queue_release(void *txq);
 uint16_t i40e_recv_pkts(void *rx_queue,
diff --git a/drivers/net/ixgbe/ixgbe_ethdev.c b/drivers/net/ixgbe/ixgbe_ethdev.c
index 22171d866..7022f2ecc 100644
--- a/drivers/net/ixgbe/ixgbe_ethdev.c
+++ b/drivers/net/ixgbe/ixgbe_ethdev.c
@@ -3665,7 +3665,7 @@ ixgbe_dev_info_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 	    hw->mac.type == ixgbe_mac_X550EM_a)
 		dev_info->tx_offload_capa |= DEV_TX_OFFLOAD_OUTER_IPV4_CKSUM;
 
-	dev_info->default_rxconf = (struct rte_eth_rxconf) {
+	dev_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_thresh = {
 			.pthresh = IXGBE_DEFAULT_RX_PTHRESH,
 			.hthresh = IXGBE_DEFAULT_RX_HTHRESH,
@@ -3675,7 +3675,7 @@ ixgbe_dev_info_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 		.rx_drop_en = 0,
 	};
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.tx_thresh = {
 			.pthresh = IXGBE_DEFAULT_TX_PTHRESH,
 			.hthresh = IXGBE_DEFAULT_TX_HTHRESH,
@@ -3776,7 +3776,7 @@ ixgbevf_dev_info_get(struct rte_eth_dev *dev,
 				DEV_TX_OFFLOAD_SCTP_CKSUM  |
 				DEV_TX_OFFLOAD_TCP_TSO;
 
-	dev_info->default_rxconf = (struct rte_eth_rxconf) {
+	dev_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_thresh = {
 			.pthresh = IXGBE_DEFAULT_RX_PTHRESH,
 			.hthresh = IXGBE_DEFAULT_RX_HTHRESH,
@@ -3786,7 +3786,7 @@ ixgbevf_dev_info_get(struct rte_eth_dev *dev,
 		.rx_drop_en = 0,
 	};
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.tx_thresh = {
 			.pthresh = IXGBE_DEFAULT_TX_PTHRESH,
 			.hthresh = IXGBE_DEFAULT_TX_HTHRESH,
diff --git a/drivers/net/ixgbe/ixgbe_ethdev.h b/drivers/net/ixgbe/ixgbe_ethdev.h
index caa50c8b9..4085a704a 100644
--- a/drivers/net/ixgbe/ixgbe_ethdev.h
+++ b/drivers/net/ixgbe/ixgbe_ethdev.h
@@ -599,12 +599,12 @@ void ixgbe_dev_tx_queue_release(void *txq);
 
 int  ixgbe_dev_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 		uint16_t nb_rx_desc, unsigned int socket_id,
-		const struct rte_eth_rxconf *rx_conf,
+		const struct rte_eth_rxq_conf *rx_conf,
 		struct rte_mempool *mb_pool);
 
 int  ixgbe_dev_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
 		uint16_t nb_tx_desc, unsigned int socket_id,
-		const struct rte_eth_txconf *tx_conf);
+		const struct rte_eth_txq_conf *tx_conf);
 
 uint32_t ixgbe_dev_rx_queue_count(struct rte_eth_dev *dev,
 		uint16_t rx_queue_id);
diff --git a/drivers/net/ixgbe/ixgbe_rxtx.c b/drivers/net/ixgbe/ixgbe_rxtx.c
index 98d0e1a86..b6b21403d 100644
--- a/drivers/net/ixgbe/ixgbe_rxtx.c
+++ b/drivers/net/ixgbe/ixgbe_rxtx.c
@@ -2397,7 +2397,7 @@ ixgbe_dev_tx_queue_setup(struct rte_eth_dev *dev,
 			 uint16_t queue_idx,
 			 uint16_t nb_desc,
 			 unsigned int socket_id,
-			 const struct rte_eth_txconf *tx_conf)
+			 const struct rte_eth_txq_conf *tx_conf)
 {
 	const struct rte_memzone *tz;
 	struct ixgbe_tx_queue *txq;
@@ -2752,7 +2752,7 @@ ixgbe_dev_rx_queue_setup(struct rte_eth_dev *dev,
 			 uint16_t queue_idx,
 			 uint16_t nb_desc,
 			 unsigned int socket_id,
-			 const struct rte_eth_rxconf *rx_conf,
+			 const struct rte_eth_rxq_conf *rx_conf,
 			 struct rte_mempool *mp)
 {
 	const struct rte_memzone *rz;
diff --git a/drivers/net/kni/rte_eth_kni.c b/drivers/net/kni/rte_eth_kni.c
index 72a2733ba..e2ef7644f 100644
--- a/drivers/net/kni/rte_eth_kni.c
+++ b/drivers/net/kni/rte_eth_kni.c
@@ -238,7 +238,7 @@ eth_kni_rx_queue_setup(struct rte_eth_dev *dev,
 		uint16_t rx_queue_id,
 		uint16_t nb_rx_desc __rte_unused,
 		unsigned int socket_id __rte_unused,
-		const struct rte_eth_rxconf *rx_conf __rte_unused,
+		const struct rte_eth_rxq_conf *rx_conf __rte_unused,
 		struct rte_mempool *mb_pool)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
@@ -258,7 +258,7 @@ eth_kni_tx_queue_setup(struct rte_eth_dev *dev,
 		uint16_t tx_queue_id,
 		uint16_t nb_tx_desc __rte_unused,
 		unsigned int socket_id __rte_unused,
-		const struct rte_eth_txconf *tx_conf __rte_unused)
+		const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
 	struct pmd_queue *q;
diff --git a/drivers/net/mlx4/mlx4.c b/drivers/net/mlx4/mlx4.c
index 055de49a3..2db8b5646 100644
--- a/drivers/net/mlx4/mlx4.c
+++ b/drivers/net/mlx4/mlx4.c
@@ -539,7 +539,7 @@ priv_set_flags(struct priv *priv, unsigned int keep, unsigned int flags)
 
 static int
 txq_setup(struct rte_eth_dev *dev, struct txq *txq, uint16_t desc,
-	  unsigned int socket, const struct rte_eth_txconf *conf);
+	  unsigned int socket, const struct rte_eth_txq_conf *conf);
 
 static void
 txq_cleanup(struct txq *txq);
@@ -547,7 +547,7 @@ txq_cleanup(struct txq *txq);
 static int
 rxq_setup(struct rte_eth_dev *dev, struct rxq *rxq, uint16_t desc,
 	  unsigned int socket, int inactive,
-	  const struct rte_eth_rxconf *conf,
+	  const struct rte_eth_rxq_conf *conf,
 	  struct rte_mempool *mp, int children_n,
 	  struct rxq *rxq_parent);
 
@@ -1762,7 +1762,7 @@ mlx4_tx_burst_secondary_setup(void *dpdk_txq, struct rte_mbuf **pkts,
  */
 static int
 txq_setup(struct rte_eth_dev *dev, struct txq *txq, uint16_t desc,
-	  unsigned int socket, const struct rte_eth_txconf *conf)
+	  unsigned int socket, const struct rte_eth_txq_conf *conf)
 {
 	struct priv *priv = mlx4_get_priv(dev);
 	struct txq tmpl = {
@@ -1954,7 +1954,7 @@ txq_setup(struct rte_eth_dev *dev, struct txq *txq, uint16_t desc,
  */
 static int
 mlx4_tx_queue_setup(struct rte_eth_dev *dev, uint16_t idx, uint16_t desc,
-		    unsigned int socket, const struct rte_eth_txconf *conf)
+		    unsigned int socket, const struct rte_eth_txq_conf *conf)
 {
 	struct priv *priv = dev->data->dev_private;
 	struct txq *txq = (*priv->txqs)[idx];
@@ -3830,7 +3830,7 @@ rxq_create_qp(struct rxq *rxq,
 static int
 rxq_setup(struct rte_eth_dev *dev, struct rxq *rxq, uint16_t desc,
 	  unsigned int socket, int inactive,
-	  const struct rte_eth_rxconf *conf,
+	  const struct rte_eth_rxq_conf *conf,
 	  struct rte_mempool *mp, int children_n,
 	  struct rxq *rxq_parent)
 {
@@ -4007,7 +4007,7 @@ rxq_setup(struct rte_eth_dev *dev, struct rxq *rxq, uint16_t desc,
  */
 static int
 mlx4_rx_queue_setup(struct rte_eth_dev *dev, uint16_t idx, uint16_t desc,
-		    unsigned int socket, const struct rte_eth_rxconf *conf,
+		    unsigned int socket, const struct rte_eth_rxq_conf *conf,
 		    struct rte_mempool *mp)
 {
 	struct rxq *parent;
diff --git a/drivers/net/mlx5/mlx5_rxq.c b/drivers/net/mlx5/mlx5_rxq.c
index 35c5cb42e..85428950c 100644
--- a/drivers/net/mlx5/mlx5_rxq.c
+++ b/drivers/net/mlx5/mlx5_rxq.c
@@ -843,7 +843,7 @@ rxq_setup(struct rxq_ctrl *tmpl)
 static int
 rxq_ctrl_setup(struct rte_eth_dev *dev, struct rxq_ctrl *rxq_ctrl,
 	       uint16_t desc, unsigned int socket,
-	       const struct rte_eth_rxconf *conf, struct rte_mempool *mp)
+	       const struct rte_eth_rxq_conf *conf, struct rte_mempool *mp)
 {
 	struct priv *priv = dev->data->dev_private;
 	struct rxq_ctrl tmpl = {
@@ -1110,7 +1110,7 @@ rxq_ctrl_setup(struct rte_eth_dev *dev, struct rxq_ctrl *rxq_ctrl,
  */
 int
 mlx5_rx_queue_setup(struct rte_eth_dev *dev, uint16_t idx, uint16_t desc,
-		    unsigned int socket, const struct rte_eth_rxconf *conf,
+		    unsigned int socket, const struct rte_eth_rxq_conf *conf,
 		    struct rte_mempool *mp)
 {
 	struct priv *priv = dev->data->dev_private;
diff --git a/drivers/net/mlx5/mlx5_rxtx.h b/drivers/net/mlx5/mlx5_rxtx.h
index 033e70f25..eb5315760 100644
--- a/drivers/net/mlx5/mlx5_rxtx.h
+++ b/drivers/net/mlx5/mlx5_rxtx.h
@@ -301,7 +301,7 @@ int priv_allow_flow_type(struct priv *, enum hash_rxq_flow_type);
 int priv_rehash_flows(struct priv *);
 void rxq_cleanup(struct rxq_ctrl *);
 int mlx5_rx_queue_setup(struct rte_eth_dev *, uint16_t, uint16_t, unsigned int,
-			const struct rte_eth_rxconf *, struct rte_mempool *);
+			const struct rte_eth_rxq_conf *, struct rte_mempool *);
 void mlx5_rx_queue_release(void *);
 int priv_rx_intr_vec_enable(struct priv *priv);
 void priv_rx_intr_vec_disable(struct priv *priv);
@@ -314,9 +314,9 @@ int mlx5_rx_intr_disable(struct rte_eth_dev *dev, uint16_t rx_queue_id);
 
 void txq_cleanup(struct txq_ctrl *);
 int txq_ctrl_setup(struct rte_eth_dev *, struct txq_ctrl *, uint16_t,
-		   unsigned int, const struct rte_eth_txconf *);
+		   unsigned int, const struct rte_eth_txq_conf *);
 int mlx5_tx_queue_setup(struct rte_eth_dev *, uint16_t, uint16_t, unsigned int,
-			const struct rte_eth_txconf *);
+			const struct rte_eth_txq_conf *);
 void mlx5_tx_queue_release(void *);
 
 /* mlx5_rxtx.c */
diff --git a/drivers/net/mlx5/mlx5_txq.c b/drivers/net/mlx5/mlx5_txq.c
index 4b0b532b1..7b8c2f766 100644
--- a/drivers/net/mlx5/mlx5_txq.c
+++ b/drivers/net/mlx5/mlx5_txq.c
@@ -211,7 +211,7 @@ txq_setup(struct txq_ctrl *tmpl, struct txq_ctrl *txq_ctrl)
 int
 txq_ctrl_setup(struct rte_eth_dev *dev, struct txq_ctrl *txq_ctrl,
 	       uint16_t desc, unsigned int socket,
-	       const struct rte_eth_txconf *conf)
+	       const struct rte_eth_txq_conf *conf)
 {
 	struct priv *priv = mlx5_get_priv(dev);
 	struct txq_ctrl tmpl = {
@@ -413,7 +413,7 @@ txq_ctrl_setup(struct rte_eth_dev *dev, struct txq_ctrl *txq_ctrl,
  */
 int
 mlx5_tx_queue_setup(struct rte_eth_dev *dev, uint16_t idx, uint16_t desc,
-		    unsigned int socket, const struct rte_eth_txconf *conf)
+		    unsigned int socket, const struct rte_eth_txq_conf *conf)
 {
 	struct priv *priv = dev->data->dev_private;
 	struct txq *txq = (*priv->txqs)[idx];
diff --git a/drivers/net/nfp/nfp_net.c b/drivers/net/nfp/nfp_net.c
index a3bf5e1f1..4122824d9 100644
--- a/drivers/net/nfp/nfp_net.c
+++ b/drivers/net/nfp/nfp_net.c
@@ -79,13 +79,13 @@ static uint16_t nfp_net_recv_pkts(void *rx_queue, struct rte_mbuf **rx_pkts,
 static void nfp_net_rx_queue_release(void *rxq);
 static int nfp_net_rx_queue_setup(struct rte_eth_dev *dev, uint16_t queue_idx,
 				  uint16_t nb_desc, unsigned int socket_id,
-				  const struct rte_eth_rxconf *rx_conf,
+				  const struct rte_eth_rxq_conf *rx_conf,
 				  struct rte_mempool *mp);
 static int nfp_net_tx_free_bufs(struct nfp_net_txq *txq);
 static void nfp_net_tx_queue_release(void *txq);
 static int nfp_net_tx_queue_setup(struct rte_eth_dev *dev, uint16_t queue_idx,
 				  uint16_t nb_desc, unsigned int socket_id,
-				  const struct rte_eth_txconf *tx_conf);
+				  const struct rte_eth_txq_conf *tx_conf);
 static int nfp_net_start(struct rte_eth_dev *dev);
 static void nfp_net_stats_get(struct rte_eth_dev *dev,
 			      struct rte_eth_stats *stats);
@@ -1119,7 +1119,7 @@ nfp_net_infos_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 					     DEV_TX_OFFLOAD_UDP_CKSUM |
 					     DEV_TX_OFFLOAD_TCP_CKSUM;
 
-	dev_info->default_rxconf = (struct rte_eth_rxconf) {
+	dev_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_thresh = {
 			.pthresh = DEFAULT_RX_PTHRESH,
 			.hthresh = DEFAULT_RX_HTHRESH,
@@ -1129,7 +1129,7 @@ nfp_net_infos_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 		.rx_drop_en = 0,
 	};
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.tx_thresh = {
 			.pthresh = DEFAULT_TX_PTHRESH,
 			.hthresh = DEFAULT_TX_HTHRESH,
@@ -1388,7 +1388,7 @@ static int
 nfp_net_rx_queue_setup(struct rte_eth_dev *dev,
 		       uint16_t queue_idx, uint16_t nb_desc,
 		       unsigned int socket_id,
-		       const struct rte_eth_rxconf *rx_conf,
+		       const struct rte_eth_rxq_conf *rx_conf,
 		       struct rte_mempool *mp)
 {
 	const struct rte_memzone *tz;
@@ -1537,7 +1537,7 @@ nfp_net_rx_fill_freelist(struct nfp_net_rxq *rxq)
 static int
 nfp_net_tx_queue_setup(struct rte_eth_dev *dev, uint16_t queue_idx,
 		       uint16_t nb_desc, unsigned int socket_id,
-		       const struct rte_eth_txconf *tx_conf)
+		       const struct rte_eth_txq_conf *tx_conf)
 {
 	const struct rte_memzone *tz;
 	struct nfp_net_txq *txq;
diff --git a/drivers/net/null/rte_eth_null.c b/drivers/net/null/rte_eth_null.c
index 5aef0591e..7ae14b77b 100644
--- a/drivers/net/null/rte_eth_null.c
+++ b/drivers/net/null/rte_eth_null.c
@@ -214,7 +214,7 @@ static int
 eth_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 		uint16_t nb_rx_desc __rte_unused,
 		unsigned int socket_id __rte_unused,
-		const struct rte_eth_rxconf *rx_conf __rte_unused,
+		const struct rte_eth_rxq_conf *rx_conf __rte_unused,
 		struct rte_mempool *mb_pool)
 {
 	struct rte_mbuf *dummy_packet;
@@ -249,7 +249,7 @@ static int
 eth_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
 		uint16_t nb_tx_desc __rte_unused,
 		unsigned int socket_id __rte_unused,
-		const struct rte_eth_txconf *tx_conf __rte_unused)
+		const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct rte_mbuf *dummy_packet;
 	struct pmd_internals *internals;
diff --git a/drivers/net/pcap/rte_eth_pcap.c b/drivers/net/pcap/rte_eth_pcap.c
index defb3b419..874856712 100644
--- a/drivers/net/pcap/rte_eth_pcap.c
+++ b/drivers/net/pcap/rte_eth_pcap.c
@@ -634,7 +634,7 @@ eth_rx_queue_setup(struct rte_eth_dev *dev,
 		uint16_t rx_queue_id,
 		uint16_t nb_rx_desc __rte_unused,
 		unsigned int socket_id __rte_unused,
-		const struct rte_eth_rxconf *rx_conf __rte_unused,
+		const struct rte_eth_rxq_conf *rx_conf __rte_unused,
 		struct rte_mempool *mb_pool)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
@@ -652,7 +652,7 @@ eth_tx_queue_setup(struct rte_eth_dev *dev,
 		uint16_t tx_queue_id,
 		uint16_t nb_tx_desc __rte_unused,
 		unsigned int socket_id __rte_unused,
-		const struct rte_eth_txconf *tx_conf __rte_unused)
+		const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
 
diff --git a/drivers/net/qede/qede_ethdev.c b/drivers/net/qede/qede_ethdev.c
index 4e9e89fad..5b6df9688 100644
--- a/drivers/net/qede/qede_ethdev.c
+++ b/drivers/net/qede/qede_ethdev.c
@@ -1293,7 +1293,7 @@ qede_dev_info_get(struct rte_eth_dev *eth_dev,
 	dev_info->hash_key_size = ECORE_RSS_KEY_SIZE * sizeof(uint32_t);
 	dev_info->flow_type_rss_offloads = (uint64_t)QEDE_RSS_OFFLOAD_ALL;
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.txq_flags = QEDE_TXQ_FLAGS,
 	};
 
diff --git a/drivers/net/qede/qede_rxtx.c b/drivers/net/qede/qede_rxtx.c
index 5c3613c7c..98da5f975 100644
--- a/drivers/net/qede/qede_rxtx.c
+++ b/drivers/net/qede/qede_rxtx.c
@@ -40,7 +40,7 @@ static inline int qede_alloc_rx_buffer(struct qede_rx_queue *rxq)
 int
 qede_rx_queue_setup(struct rte_eth_dev *dev, uint16_t queue_idx,
 		    uint16_t nb_desc, unsigned int socket_id,
-		    __rte_unused const struct rte_eth_rxconf *rx_conf,
+		    __rte_unused const struct rte_eth_rxq_conf *rx_conf,
 		    struct rte_mempool *mp)
 {
 	struct qede_dev *qdev = QEDE_INIT_QDEV(dev);
@@ -238,7 +238,7 @@ qede_tx_queue_setup(struct rte_eth_dev *dev,
 		    uint16_t queue_idx,
 		    uint16_t nb_desc,
 		    unsigned int socket_id,
-		    const struct rte_eth_txconf *tx_conf)
+		    const struct rte_eth_txq_conf *tx_conf)
 {
 	struct qede_dev *qdev = dev->data->dev_private;
 	struct ecore_dev *edev = &qdev->edev;
diff --git a/drivers/net/qede/qede_rxtx.h b/drivers/net/qede/qede_rxtx.h
index b551fd6ae..0c10b8ebe 100644
--- a/drivers/net/qede/qede_rxtx.h
+++ b/drivers/net/qede/qede_rxtx.h
@@ -225,14 +225,14 @@ struct qede_fastpath {
  */
 int qede_rx_queue_setup(struct rte_eth_dev *dev, uint16_t queue_idx,
 			uint16_t nb_desc, unsigned int socket_id,
-			const struct rte_eth_rxconf *rx_conf,
+			const struct rte_eth_rxq_conf *rx_conf,
 			struct rte_mempool *mp);
 
 int qede_tx_queue_setup(struct rte_eth_dev *dev,
 			uint16_t queue_idx,
 			uint16_t nb_desc,
 			unsigned int socket_id,
-			const struct rte_eth_txconf *tx_conf);
+			const struct rte_eth_txq_conf *tx_conf);
 
 void qede_rx_queue_release(void *rx_queue);
 
diff --git a/drivers/net/ring/rte_eth_ring.c b/drivers/net/ring/rte_eth_ring.c
index 464d3d384..6d077e3cf 100644
--- a/drivers/net/ring/rte_eth_ring.c
+++ b/drivers/net/ring/rte_eth_ring.c
@@ -155,11 +155,12 @@ eth_dev_set_link_up(struct rte_eth_dev *dev)
 }
 
 static int
-eth_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
-				    uint16_t nb_rx_desc __rte_unused,
-				    unsigned int socket_id __rte_unused,
-				    const struct rte_eth_rxconf *rx_conf __rte_unused,
-				    struct rte_mempool *mb_pool __rte_unused)
+eth_rx_queue_setup(struct rte_eth_dev *dev,
+		   uint16_t rx_queue_id,
+		   uint16_t nb_rx_desc __rte_unused,
+		   unsigned int socket_id __rte_unused,
+		   const struct rte_eth_rxq_conf *rx_conf __rte_unused,
+		   struct rte_mempool *mb_pool __rte_unused)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
 	dev->data->rx_queues[rx_queue_id] = &internals->rx_ring_queues[rx_queue_id];
@@ -167,10 +168,11 @@ eth_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 }
 
 static int
-eth_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
-				    uint16_t nb_tx_desc __rte_unused,
-				    unsigned int socket_id __rte_unused,
-				    const struct rte_eth_txconf *tx_conf __rte_unused)
+eth_tx_queue_setup(struct rte_eth_dev *dev,
+		   uint16_t tx_queue_id,
+		   uint16_t nb_tx_desc __rte_unused,
+		   unsigned int socket_id __rte_unused,
+		   const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
 	dev->data->tx_queues[tx_queue_id] = &internals->tx_ring_queues[tx_queue_id];
diff --git a/drivers/net/sfc/sfc_ethdev.c b/drivers/net/sfc/sfc_ethdev.c
index 2b037d863..959a2b42f 100644
--- a/drivers/net/sfc/sfc_ethdev.c
+++ b/drivers/net/sfc/sfc_ethdev.c
@@ -404,7 +404,7 @@ sfc_dev_allmulti_disable(struct rte_eth_dev *dev)
 static int
 sfc_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 		   uint16_t nb_rx_desc, unsigned int socket_id,
-		   const struct rte_eth_rxconf *rx_conf,
+		   const struct rte_eth_rxq_conf *rx_conf,
 		   struct rte_mempool *mb_pool)
 {
 	struct sfc_adapter *sa = dev->data->dev_private;
@@ -461,7 +461,7 @@ sfc_rx_queue_release(void *queue)
 static int
 sfc_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
 		   uint16_t nb_tx_desc, unsigned int socket_id,
-		   const struct rte_eth_txconf *tx_conf)
+		   const struct rte_eth_txq_conf *tx_conf)
 {
 	struct sfc_adapter *sa = dev->data->dev_private;
 	int rc;
diff --git a/drivers/net/sfc/sfc_rx.c b/drivers/net/sfc/sfc_rx.c
index 79ed046ce..079df6272 100644
--- a/drivers/net/sfc/sfc_rx.c
+++ b/drivers/net/sfc/sfc_rx.c
@@ -772,7 +772,7 @@ sfc_rx_qstop(struct sfc_adapter *sa, unsigned int sw_index)
 
 static int
 sfc_rx_qcheck_conf(struct sfc_adapter *sa, uint16_t nb_rx_desc,
-		   const struct rte_eth_rxconf *rx_conf)
+		   const struct rte_eth_rxq_conf *rx_conf)
 {
 	const uint16_t rx_free_thresh_max = EFX_RXQ_LIMIT(nb_rx_desc);
 	int rc = 0;
@@ -903,7 +903,7 @@ sfc_rx_mb_pool_buf_size(struct sfc_adapter *sa, struct rte_mempool *mb_pool)
 int
 sfc_rx_qinit(struct sfc_adapter *sa, unsigned int sw_index,
 	     uint16_t nb_rx_desc, unsigned int socket_id,
-	     const struct rte_eth_rxconf *rx_conf,
+	     const struct rte_eth_rxq_conf *rx_conf,
 	     struct rte_mempool *mb_pool)
 {
 	const efx_nic_cfg_t *encp = efx_nic_cfg_get(sa->nic);
diff --git a/drivers/net/sfc/sfc_rx.h b/drivers/net/sfc/sfc_rx.h
index 9e6282ead..126c41089 100644
--- a/drivers/net/sfc/sfc_rx.h
+++ b/drivers/net/sfc/sfc_rx.h
@@ -156,7 +156,7 @@ void sfc_rx_stop(struct sfc_adapter *sa);
 
 int sfc_rx_qinit(struct sfc_adapter *sa, unsigned int rx_queue_id,
 		 uint16_t nb_rx_desc, unsigned int socket_id,
-		 const struct rte_eth_rxconf *rx_conf,
+		 const struct rte_eth_rxq_conf *rx_conf,
 		 struct rte_mempool *mb_pool);
 void sfc_rx_qfini(struct sfc_adapter *sa, unsigned int sw_index);
 int sfc_rx_qstart(struct sfc_adapter *sa, unsigned int sw_index);
diff --git a/drivers/net/sfc/sfc_tx.c b/drivers/net/sfc/sfc_tx.c
index bf596017a..fe030baa4 100644
--- a/drivers/net/sfc/sfc_tx.c
+++ b/drivers/net/sfc/sfc_tx.c
@@ -58,7 +58,7 @@
 
 static int
 sfc_tx_qcheck_conf(struct sfc_adapter *sa, uint16_t nb_tx_desc,
-		   const struct rte_eth_txconf *tx_conf)
+		   const struct rte_eth_txq_conf *tx_conf)
 {
 	unsigned int flags = tx_conf->txq_flags;
 	const efx_nic_cfg_t *encp = efx_nic_cfg_get(sa->nic);
@@ -128,7 +128,7 @@ sfc_tx_qflush_done(struct sfc_txq *txq)
 int
 sfc_tx_qinit(struct sfc_adapter *sa, unsigned int sw_index,
 	     uint16_t nb_tx_desc, unsigned int socket_id,
-	     const struct rte_eth_txconf *tx_conf)
+	     const struct rte_eth_txq_conf *tx_conf)
 {
 	const efx_nic_cfg_t *encp = efx_nic_cfg_get(sa->nic);
 	struct sfc_txq_info *txq_info;
diff --git a/drivers/net/sfc/sfc_tx.h b/drivers/net/sfc/sfc_tx.h
index 0c1c7083b..90b5eb7d7 100644
--- a/drivers/net/sfc/sfc_tx.h
+++ b/drivers/net/sfc/sfc_tx.h
@@ -141,7 +141,7 @@ void sfc_tx_close(struct sfc_adapter *sa);
 
 int sfc_tx_qinit(struct sfc_adapter *sa, unsigned int sw_index,
 		 uint16_t nb_tx_desc, unsigned int socket_id,
-		 const struct rte_eth_txconf *tx_conf);
+		 const struct rte_eth_txq_conf *tx_conf);
 void sfc_tx_qfini(struct sfc_adapter *sa, unsigned int sw_index);
 
 void sfc_tx_qflush_done(struct sfc_txq *txq);
diff --git a/drivers/net/szedata2/rte_eth_szedata2.c b/drivers/net/szedata2/rte_eth_szedata2.c
index 9c0d57cc1..6ba24a263 100644
--- a/drivers/net/szedata2/rte_eth_szedata2.c
+++ b/drivers/net/szedata2/rte_eth_szedata2.c
@@ -1253,7 +1253,7 @@ eth_rx_queue_setup(struct rte_eth_dev *dev,
 		uint16_t rx_queue_id,
 		uint16_t nb_rx_desc __rte_unused,
 		unsigned int socket_id __rte_unused,
-		const struct rte_eth_rxconf *rx_conf __rte_unused,
+		const struct rte_eth_rxq_conf *rx_conf __rte_unused,
 		struct rte_mempool *mb_pool)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
@@ -1287,7 +1287,7 @@ eth_tx_queue_setup(struct rte_eth_dev *dev,
 		uint16_t tx_queue_id,
 		uint16_t nb_tx_desc __rte_unused,
 		unsigned int socket_id __rte_unused,
-		const struct rte_eth_txconf *tx_conf __rte_unused)
+		const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
 	struct szedata2_tx_queue *txq = &internals->tx_queue[tx_queue_id];
diff --git a/drivers/net/tap/rte_eth_tap.c b/drivers/net/tap/rte_eth_tap.c
index 9acea8398..5a1125a7a 100644
--- a/drivers/net/tap/rte_eth_tap.c
+++ b/drivers/net/tap/rte_eth_tap.c
@@ -918,7 +918,7 @@ tap_rx_queue_setup(struct rte_eth_dev *dev,
 		   uint16_t rx_queue_id,
 		   uint16_t nb_rx_desc,
 		   unsigned int socket_id,
-		   const struct rte_eth_rxconf *rx_conf __rte_unused,
+		   const struct rte_eth_rxq_conf *rx_conf __rte_unused,
 		   struct rte_mempool *mp)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
@@ -997,7 +997,7 @@ tap_tx_queue_setup(struct rte_eth_dev *dev,
 		   uint16_t tx_queue_id,
 		   uint16_t nb_tx_desc __rte_unused,
 		   unsigned int socket_id __rte_unused,
-		   const struct rte_eth_txconf *tx_conf __rte_unused)
+		   const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct pmd_internals *internals = dev->data->dev_private;
 	int ret;
diff --git a/drivers/net/thunderx/nicvf_ethdev.c b/drivers/net/thunderx/nicvf_ethdev.c
index edc17f1d4..3ddca8b49 100644
--- a/drivers/net/thunderx/nicvf_ethdev.c
+++ b/drivers/net/thunderx/nicvf_ethdev.c
@@ -936,7 +936,7 @@ nicvf_set_rx_function(struct rte_eth_dev *dev)
 static int
 nicvf_dev_tx_queue_setup(struct rte_eth_dev *dev, uint16_t qidx,
 			 uint16_t nb_desc, unsigned int socket_id,
-			 const struct rte_eth_txconf *tx_conf)
+			 const struct rte_eth_txq_conf *tx_conf)
 {
 	uint16_t tx_free_thresh;
 	uint8_t is_single_pool;
@@ -1261,7 +1261,7 @@ nicvf_rxq_mbuf_setup(struct nicvf_rxq *rxq)
 static int
 nicvf_dev_rx_queue_setup(struct rte_eth_dev *dev, uint16_t qidx,
 			 uint16_t nb_desc, unsigned int socket_id,
-			 const struct rte_eth_rxconf *rx_conf,
+			 const struct rte_eth_rxq_conf *rx_conf,
 			 struct rte_mempool *mp)
 {
 	uint16_t rx_free_thresh;
@@ -1403,12 +1403,12 @@ nicvf_dev_info_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 	if (nicvf_hw_cap(nic) & NICVF_CAP_TUNNEL_PARSING)
 		dev_info->flow_type_rss_offloads |= NICVF_RSS_OFFLOAD_TUNNEL;
 
-	dev_info->default_rxconf = (struct rte_eth_rxconf) {
+	dev_info->default_rxconf = (struct rte_eth_rxq_conf) {
 		.rx_free_thresh = NICVF_DEFAULT_RX_FREE_THRESH,
 		.rx_drop_en = 0,
 	};
 
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.tx_free_thresh = NICVF_DEFAULT_TX_FREE_THRESH,
 		.txq_flags =
 			ETH_TXQ_FLAGS_NOMULTSEGS  |
diff --git a/drivers/net/vhost/rte_eth_vhost.c b/drivers/net/vhost/rte_eth_vhost.c
index 0dac5e60e..c90d06bd7 100644
--- a/drivers/net/vhost/rte_eth_vhost.c
+++ b/drivers/net/vhost/rte_eth_vhost.c
@@ -831,7 +831,7 @@ static int
 eth_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 		   uint16_t nb_rx_desc __rte_unused,
 		   unsigned int socket_id,
-		   const struct rte_eth_rxconf *rx_conf __rte_unused,
+		   const struct rte_eth_rxq_conf *rx_conf __rte_unused,
 		   struct rte_mempool *mb_pool)
 {
 	struct vhost_queue *vq;
@@ -854,7 +854,7 @@ static int
 eth_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
 		   uint16_t nb_tx_desc __rte_unused,
 		   unsigned int socket_id,
-		   const struct rte_eth_txconf *tx_conf __rte_unused)
+		   const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct vhost_queue *vq;
 
diff --git a/drivers/net/virtio/virtio_ethdev.c b/drivers/net/virtio/virtio_ethdev.c
index e320811ed..763b30e9a 100644
--- a/drivers/net/virtio/virtio_ethdev.c
+++ b/drivers/net/virtio/virtio_ethdev.c
@@ -1891,7 +1891,7 @@ virtio_dev_info_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 	dev_info->min_rx_bufsize = VIRTIO_MIN_RX_BUFSIZE;
 	dev_info->max_rx_pktlen = VIRTIO_MAX_RX_PKTLEN;
 	dev_info->max_mac_addrs = VIRTIO_MAX_MAC_ADDRS;
-	dev_info->default_txconf = (struct rte_eth_txconf) {
+	dev_info->default_txconf = (struct rte_eth_txq_conf) {
 		.txq_flags = ETH_TXQ_FLAGS_NOOFFLOADS
 	};
 
diff --git a/drivers/net/virtio/virtio_ethdev.h b/drivers/net/virtio/virtio_ethdev.h
index c3413c6d9..57f0d7ad2 100644
--- a/drivers/net/virtio/virtio_ethdev.h
+++ b/drivers/net/virtio/virtio_ethdev.h
@@ -89,12 +89,12 @@ int virtio_dev_rx_queue_done(void *rxq, uint16_t offset);
 
 int  virtio_dev_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 		uint16_t nb_rx_desc, unsigned int socket_id,
-		const struct rte_eth_rxconf *rx_conf,
+		const struct rte_eth_rxq_conf *rx_conf,
 		struct rte_mempool *mb_pool);
 
 int  virtio_dev_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
 		uint16_t nb_tx_desc, unsigned int socket_id,
-		const struct rte_eth_txconf *tx_conf);
+		const struct rte_eth_txq_conf *tx_conf);
 
 uint16_t virtio_recv_pkts(void *rx_queue, struct rte_mbuf **rx_pkts,
 		uint16_t nb_pkts);
diff --git a/drivers/net/vmxnet3/vmxnet3_ethdev.h b/drivers/net/vmxnet3/vmxnet3_ethdev.h
index b48058afc..98389fa74 100644
--- a/drivers/net/vmxnet3/vmxnet3_ethdev.h
+++ b/drivers/net/vmxnet3/vmxnet3_ethdev.h
@@ -189,11 +189,11 @@ void vmxnet3_dev_tx_queue_release(void *txq);
 
 int  vmxnet3_dev_rx_queue_setup(struct rte_eth_dev *dev, uint16_t rx_queue_id,
 				uint16_t nb_rx_desc, unsigned int socket_id,
-				const struct rte_eth_rxconf *rx_conf,
+				const struct rte_eth_rxq_conf *rx_conf,
 				struct rte_mempool *mb_pool);
 int  vmxnet3_dev_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
 				uint16_t nb_tx_desc, unsigned int socket_id,
-				const struct rte_eth_txconf *tx_conf);
+				const struct rte_eth_txq_conf *tx_conf);
 
 int vmxnet3_dev_rxtx_init(struct rte_eth_dev *dev);
 
diff --git a/drivers/net/vmxnet3/vmxnet3_rxtx.c b/drivers/net/vmxnet3/vmxnet3_rxtx.c
index d9cf43739..cfdf72f7f 100644
--- a/drivers/net/vmxnet3/vmxnet3_rxtx.c
+++ b/drivers/net/vmxnet3/vmxnet3_rxtx.c
@@ -888,7 +888,7 @@ vmxnet3_dev_tx_queue_setup(struct rte_eth_dev *dev,
 			   uint16_t queue_idx,
 			   uint16_t nb_desc,
 			   unsigned int socket_id,
-			   const struct rte_eth_txconf *tx_conf)
+			   const struct rte_eth_txq_conf *tx_conf)
 {
 	struct vmxnet3_hw *hw = dev->data->dev_private;
 	const struct rte_memzone *mz;
@@ -993,7 +993,7 @@ vmxnet3_dev_rx_queue_setup(struct rte_eth_dev *dev,
 			   uint16_t queue_idx,
 			   uint16_t nb_desc,
 			   unsigned int socket_id,
-			   __rte_unused const struct rte_eth_rxconf *rx_conf,
+			   __rte_unused const struct rte_eth_rxq_conf *rx_conf,
 			   struct rte_mempool *mp)
 {
 	const struct rte_memzone *mz;
diff --git a/drivers/net/xenvirt/rte_eth_xenvirt.c b/drivers/net/xenvirt/rte_eth_xenvirt.c
index e404b7755..792fbfb0a 100644
--- a/drivers/net/xenvirt/rte_eth_xenvirt.c
+++ b/drivers/net/xenvirt/rte_eth_xenvirt.c
@@ -492,11 +492,12 @@ virtio_queue_setup(struct rte_eth_dev *dev, int queue_type)
 }
 
 static int
-eth_rx_queue_setup(struct rte_eth_dev *dev,uint16_t rx_queue_id,
-				uint16_t nb_rx_desc __rte_unused,
-				unsigned int socket_id __rte_unused,
-				const struct rte_eth_rxconf *rx_conf __rte_unused,
-				struct rte_mempool *mb_pool)
+eth_rx_queue_setup(struct rte_eth_dev *dev,
+		   uint16_t rx_queue_id,
+		   uint16_t nb_rx_desc __rte_unused,
+		   unsigned int socket_id __rte_unused,
+		   const struct rte_eth_rxq_conf *rx_conf __rte_unused,
+		   struct rte_mempool *mb_pool)
 {
 	struct virtqueue *vq;
 	vq = dev->data->rx_queues[rx_queue_id] = virtio_queue_setup(dev, VTNET_RQ);
@@ -505,10 +506,11 @@ eth_rx_queue_setup(struct rte_eth_dev *dev,uint16_t rx_queue_id,
 }
 
 static int
-eth_tx_queue_setup(struct rte_eth_dev *dev, uint16_t tx_queue_id,
-				uint16_t nb_tx_desc __rte_unused,
-				unsigned int socket_id __rte_unused,
-				const struct rte_eth_txconf *tx_conf __rte_unused)
+eth_tx_queue_setup(struct rte_eth_dev *dev,
+		   uint16_t tx_queue_id,
+		   uint16_t nb_tx_desc __rte_unused,
+		   unsigned int socket_id __rte_unused,
+		   const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	dev->data->tx_queues[tx_queue_id] = virtio_queue_setup(dev, VTNET_TQ);
 	return 0;
diff --git a/examples/ip_fragmentation/main.c b/examples/ip_fragmentation/main.c
index 8c0e17911..15f9426f2 100644
--- a/examples/ip_fragmentation/main.c
+++ b/examples/ip_fragmentation/main.c
@@ -869,7 +869,7 @@ main(int argc, char **argv)
 {
 	struct lcore_queue_conf *qconf;
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_txq_conf *txconf;
 	struct rx_queue *rxq;
 	int socket, ret;
 	unsigned nb_ports;
diff --git a/examples/ip_pipeline/app.h b/examples/ip_pipeline/app.h
index e41290e74..59bb1bac8 100644
--- a/examples/ip_pipeline/app.h
+++ b/examples/ip_pipeline/app.h
@@ -103,7 +103,7 @@ struct app_pktq_hwq_in_params {
 	uint32_t size;
 	uint32_t burst;
 
-	struct rte_eth_rxconf conf;
+	struct rte_eth_rxq_conf conf;
 };
 
 struct app_pktq_hwq_out_params {
@@ -113,7 +113,7 @@ struct app_pktq_hwq_out_params {
 	uint32_t burst;
 	uint32_t dropless;
 	uint64_t n_retries;
-	struct rte_eth_txconf conf;
+	struct rte_eth_txq_conf conf;
 };
 
 struct app_pktq_swq_params {
diff --git a/examples/ip_reassembly/main.c b/examples/ip_reassembly/main.c
index e62636cb4..746140f60 100644
--- a/examples/ip_reassembly/main.c
+++ b/examples/ip_reassembly/main.c
@@ -1017,7 +1017,7 @@ main(int argc, char **argv)
 {
 	struct lcore_queue_conf *qconf;
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_txq_conf *txconf;
 	struct rx_queue *rxq;
 	int ret, socket;
 	unsigned nb_ports;
diff --git a/examples/ipsec-secgw/ipsec-secgw.c b/examples/ipsec-secgw/ipsec-secgw.c
index 99dc270cb..807d079cf 100644
--- a/examples/ipsec-secgw/ipsec-secgw.c
+++ b/examples/ipsec-secgw/ipsec-secgw.c
@@ -1325,7 +1325,7 @@ static void
 port_init(uint8_t portid)
 {
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_txq_conf *txconf;
 	uint16_t nb_tx_queue, nb_rx_queue;
 	uint16_t tx_queueid, rx_queueid, queue, lcore_id;
 	int32_t ret, socket_id;
diff --git a/examples/ipv4_multicast/main.c b/examples/ipv4_multicast/main.c
index 9a13d3530..a3c060778 100644
--- a/examples/ipv4_multicast/main.c
+++ b/examples/ipv4_multicast/main.c
@@ -668,7 +668,7 @@ main(int argc, char **argv)
 {
 	struct lcore_queue_conf *qconf;
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_txq_conf *txconf;
 	int ret;
 	uint16_t queueid;
 	unsigned lcore_id = 0, rx_lcore_id = 0;
diff --git a/examples/l3fwd-acl/main.c b/examples/l3fwd-acl/main.c
index 8eff4de41..03124e142 100644
--- a/examples/l3fwd-acl/main.c
+++ b/examples/l3fwd-acl/main.c
@@ -1887,7 +1887,7 @@ main(int argc, char **argv)
 {
 	struct lcore_conf *qconf;
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_txq_conf *txconf;
 	int ret;
 	unsigned nb_ports;
 	uint16_t queueid;
diff --git a/examples/l3fwd-power/main.c b/examples/l3fwd-power/main.c
index fd442f5ef..f54decd20 100644
--- a/examples/l3fwd-power/main.c
+++ b/examples/l3fwd-power/main.c
@@ -1643,7 +1643,7 @@ main(int argc, char **argv)
 {
 	struct lcore_conf *qconf;
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_txq_conf *txconf;
 	int ret;
 	unsigned nb_ports;
 	uint16_t queueid;
diff --git a/examples/l3fwd-vf/main.c b/examples/l3fwd-vf/main.c
index 34e4a6bef..9a1ff8748 100644
--- a/examples/l3fwd-vf/main.c
+++ b/examples/l3fwd-vf/main.c
@@ -950,7 +950,7 @@ main(int argc, char **argv)
 {
 	struct lcore_conf *qconf;
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_txq_conf *txconf;
 	int ret;
 	unsigned nb_ports;
 	uint16_t queueid;
diff --git a/examples/l3fwd/main.c b/examples/l3fwd/main.c
index 81995fdbe..2e904b7ae 100644
--- a/examples/l3fwd/main.c
+++ b/examples/l3fwd/main.c
@@ -844,7 +844,7 @@ main(int argc, char **argv)
 {
 	struct lcore_conf *qconf;
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_txq_conf *txconf;
 	int ret;
 	unsigned nb_ports;
 	uint16_t queueid;
diff --git a/examples/netmap_compat/lib/compat_netmap.c b/examples/netmap_compat/lib/compat_netmap.c
index af2d9f3f7..2c245d1df 100644
--- a/examples/netmap_compat/lib/compat_netmap.c
+++ b/examples/netmap_compat/lib/compat_netmap.c
@@ -57,8 +57,8 @@ struct netmap_port {
 	struct rte_mempool   *pool;
 	struct netmap_if     *nmif;
 	struct rte_eth_conf   eth_conf;
-	struct rte_eth_txconf tx_conf;
-	struct rte_eth_rxconf rx_conf;
+	struct rte_eth_txq_conf tx_conf;
+	struct rte_eth_rxq_conf rx_conf;
 	int32_t  socket_id;
 	uint16_t nr_tx_rings;
 	uint16_t nr_rx_rings;
diff --git a/examples/performance-thread/l3fwd-thread/main.c b/examples/performance-thread/l3fwd-thread/main.c
index 7954b9744..e72b86e78 100644
--- a/examples/performance-thread/l3fwd-thread/main.c
+++ b/examples/performance-thread/l3fwd-thread/main.c
@@ -3493,7 +3493,7 @@ int
 main(int argc, char **argv)
 {
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_txq_conf *txconf;
 	int ret;
 	int i;
 	unsigned nb_ports;
diff --git a/examples/ptpclient/ptpclient.c b/examples/ptpclient/ptpclient.c
index ddfcdb832..ac350f5fb 100644
--- a/examples/ptpclient/ptpclient.c
+++ b/examples/ptpclient/ptpclient.c
@@ -237,7 +237,7 @@ port_init(uint8_t port, struct rte_mempool *mbuf_pool)
 	/* Allocate and set up 1 TX queue per Ethernet port. */
 	for (q = 0; q < tx_rings; q++) {
 		/* Setup txq_flags */
-		struct rte_eth_txconf *txconf;
+		struct rte_eth_txq_conf *txconf;
 
 		rte_eth_dev_info_get(q, &dev_info);
 		txconf = &dev_info.default_txconf;
diff --git a/examples/qos_sched/init.c b/examples/qos_sched/init.c
index a82cbd7d5..955d051d2 100644
--- a/examples/qos_sched/init.c
+++ b/examples/qos_sched/init.c
@@ -104,8 +104,8 @@ app_init_port(uint8_t portid, struct rte_mempool *mp)
 {
 	int ret;
 	struct rte_eth_link link;
-	struct rte_eth_rxconf rx_conf;
-	struct rte_eth_txconf tx_conf;
+	struct rte_eth_rxq_conf rx_conf;
+	struct rte_eth_txq_conf tx_conf;
 	uint16_t rx_size;
 	uint16_t tx_size;
 
diff --git a/examples/tep_termination/vxlan_setup.c b/examples/tep_termination/vxlan_setup.c
index 050bb32d3..8d61e8891 100644
--- a/examples/tep_termination/vxlan_setup.c
+++ b/examples/tep_termination/vxlan_setup.c
@@ -138,8 +138,8 @@ vxlan_port_init(uint8_t port, struct rte_mempool *mbuf_pool)
 	uint16_t rx_ring_size = RTE_TEST_RX_DESC_DEFAULT;
 	uint16_t tx_ring_size = RTE_TEST_TX_DESC_DEFAULT;
 	struct rte_eth_udp_tunnel tunnel_udp;
-	struct rte_eth_rxconf *rxconf;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_rxq_conf *rxconf;
+	struct rte_eth_txq_conf *txconf;
 	struct vxlan_conf *pconf = &vxdev;
 
 	pconf->dst_port = udp_port;
diff --git a/examples/vhost/main.c b/examples/vhost/main.c
index 4d1589d06..75c4c8341 100644
--- a/examples/vhost/main.c
+++ b/examples/vhost/main.c
@@ -269,8 +269,8 @@ port_init(uint8_t port)
 {
 	struct rte_eth_dev_info dev_info;
 	struct rte_eth_conf port_conf;
-	struct rte_eth_rxconf *rxconf;
-	struct rte_eth_txconf *txconf;
+	struct rte_eth_rxq_conf *rxconf;
+	struct rte_eth_txq_conf *txconf;
 	int16_t rx_rings, tx_rings;
 	uint16_t rx_ring_size, tx_ring_size;
 	int retval;
diff --git a/examples/vhost_xen/main.c b/examples/vhost_xen/main.c
index eba4d35aa..852269cdc 100644
--- a/examples/vhost_xen/main.c
+++ b/examples/vhost_xen/main.c
@@ -276,7 +276,7 @@ static inline int
 port_init(uint8_t port, struct rte_mempool *mbuf_pool)
 {
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_rxconf *rxconf;
+	struct rte_eth_rxq_conf *rxconf;
 	struct rte_eth_conf port_conf;
 	uint16_t rx_rings, tx_rings = (uint16_t)rte_lcore_count();
 	uint16_t rx_ring_size = RTE_TEST_RX_DESC_DEFAULT;
diff --git a/examples/vmdq/main.c b/examples/vmdq/main.c
index 8949a1156..5c3a73789 100644
--- a/examples/vmdq/main.c
+++ b/examples/vmdq/main.c
@@ -189,7 +189,7 @@ static inline int
 port_init(uint8_t port, struct rte_mempool *mbuf_pool)
 {
 	struct rte_eth_dev_info dev_info;
-	struct rte_eth_rxconf *rxconf;
+	struct rte_eth_rxq_conf *rxconf;
 	struct rte_eth_conf port_conf;
 	uint16_t rxRings, txRings;
 	uint16_t rxRingSize = RTE_TEST_RX_DESC_DEFAULT;
diff --git a/lib/librte_ether/rte_ethdev.c b/lib/librte_ether/rte_ethdev.c
index 0597641ee..da2424cc4 100644
--- a/lib/librte_ether/rte_ethdev.c
+++ b/lib/librte_ether/rte_ethdev.c
@@ -997,7 +997,7 @@ rte_eth_dev_close(uint8_t port_id)
 int
 rte_eth_rx_queue_setup(uint8_t port_id, uint16_t rx_queue_id,
 		       uint16_t nb_rx_desc, unsigned int socket_id,
-		       const struct rte_eth_rxconf *rx_conf,
+		       const struct rte_eth_rxq_conf *rx_conf,
 		       struct rte_mempool *mp)
 {
 	int ret;
@@ -1088,7 +1088,7 @@ rte_eth_rx_queue_setup(uint8_t port_id, uint16_t rx_queue_id,
 int
 rte_eth_tx_queue_setup(uint8_t port_id, uint16_t tx_queue_id,
 		       uint16_t nb_tx_desc, unsigned int socket_id,
-		       const struct rte_eth_txconf *tx_conf)
+		       const struct rte_eth_txq_conf *tx_conf)
 {
 	struct rte_eth_dev *dev;
 	struct rte_eth_dev_info dev_info;
diff --git a/lib/librte_ether/rte_ethdev.h b/lib/librte_ether/rte_ethdev.h
index 0adf3274a..c40db4ee0 100644
--- a/lib/librte_ether/rte_ethdev.h
+++ b/lib/librte_ether/rte_ethdev.h
@@ -686,7 +686,7 @@ struct rte_eth_txmode {
 /**
  * A structure used to configure an RX ring of an Ethernet port.
  */
-struct rte_eth_rxconf {
+struct rte_eth_rxq_conf {
 	struct rte_eth_thresh rx_thresh; /**< RX ring threshold registers. */
 	uint16_t rx_free_thresh; /**< Drives the freeing of RX descriptors. */
 	uint8_t rx_drop_en; /**< Drop packets if no descriptors are available. */
@@ -709,7 +709,7 @@ struct rte_eth_rxconf {
 /**
  * A structure used to configure a TX ring of an Ethernet port.
  */
-struct rte_eth_txconf {
+struct rte_eth_txq_conf {
 	struct rte_eth_thresh tx_thresh; /**< TX ring threshold registers. */
 	uint16_t tx_rs_thresh; /**< Drives the setting of RS bit on TXDs. */
 	uint16_t tx_free_thresh; /**< Start freeing TX buffers if there are
@@ -956,8 +956,10 @@ struct rte_eth_dev_info {
 	uint8_t hash_key_size; /**< Hash key size in bytes */
 	/** Bit mask of RSS offloads, the bit offset also means flow type */
 	uint64_t flow_type_rss_offloads;
-	struct rte_eth_rxconf default_rxconf; /**< Default RX configuration */
-	struct rte_eth_txconf default_txconf; /**< Default TX configuration */
+	struct rte_eth_rxq_conf default_rxconf;
+	/**< Default RX queue configuration */
+	struct rte_eth_txq_conf default_txconf;
+	/**< Default TX queue configuration */
 	uint16_t vmdq_queue_base; /**< First queue ID for VMDQ pools. */
 	uint16_t vmdq_queue_num;  /**< Queue number for VMDQ pools. */
 	uint16_t vmdq_pool_base;  /**< First ID of VMDQ pools. */
@@ -975,7 +977,7 @@ struct rte_eth_dev_info {
  */
 struct rte_eth_rxq_info {
 	struct rte_mempool *mp;     /**< mempool used by that queue. */
-	struct rte_eth_rxconf conf; /**< queue config parameters. */
+	struct rte_eth_rxq_conf conf; /**< queue config parameters. */
 	uint8_t scattered_rx;       /**< scattered packets RX supported. */
 	uint16_t nb_desc;           /**< configured number of RXDs. */
 } __rte_cache_min_aligned;
@@ -985,7 +987,7 @@ struct rte_eth_rxq_info {
  * Used to retieve information about configured queue.
  */
 struct rte_eth_txq_info {
-	struct rte_eth_txconf conf; /**< queue config parameters. */
+	struct rte_eth_txq_conf conf; /**< queue config parameters. */
 	uint16_t nb_desc;           /**< configured number of TXDs. */
 } __rte_cache_min_aligned;
 
@@ -1185,7 +1187,7 @@ typedef int (*eth_rx_queue_setup_t)(struct rte_eth_dev *dev,
 				    uint16_t rx_queue_id,
 				    uint16_t nb_rx_desc,
 				    unsigned int socket_id,
-				    const struct rte_eth_rxconf *rx_conf,
+				    const struct rte_eth_rxq_conf *rx_conf,
 				    struct rte_mempool *mb_pool);
 /**< @internal Set up a receive queue of an Ethernet device. */
 
@@ -1193,7 +1195,7 @@ typedef int (*eth_tx_queue_setup_t)(struct rte_eth_dev *dev,
 				    uint16_t tx_queue_id,
 				    uint16_t nb_tx_desc,
 				    unsigned int socket_id,
-				    const struct rte_eth_txconf *tx_conf);
+				    const struct rte_eth_txq_conf *tx_conf);
 /**< @internal Setup a transmit queue of an Ethernet device. */
 
 typedef int (*eth_rx_enable_intr_t)(struct rte_eth_dev *dev,
@@ -1937,7 +1939,7 @@ void _rte_eth_dev_reset(struct rte_eth_dev *dev);
  */
 int rte_eth_rx_queue_setup(uint8_t port_id, uint16_t rx_queue_id,
 		uint16_t nb_rx_desc, unsigned int socket_id,
-		const struct rte_eth_rxconf *rx_conf,
+		const struct rte_eth_rxq_conf *rx_conf,
 		struct rte_mempool *mb_pool);
 
 /**
@@ -1985,7 +1987,7 @@ int rte_eth_rx_queue_setup(uint8_t port_id, uint16_t rx_queue_id,
  */
 int rte_eth_tx_queue_setup(uint8_t port_id, uint16_t tx_queue_id,
 		uint16_t nb_tx_desc, unsigned int socket_id,
-		const struct rte_eth_txconf *tx_conf);
+		const struct rte_eth_txq_conf *tx_conf);
 
 /**
  * Return the NUMA socket to which an Ethernet device is connected
@@ -2972,7 +2974,7 @@ static inline int rte_eth_tx_descriptor_status(uint8_t port_id,
  *
  * If the PMD is DEV_TX_OFFLOAD_MT_LOCKFREE capable, multiple threads can
  * invoke this function concurrently on the same tx queue without SW lock.
- * @see rte_eth_dev_info_get, struct rte_eth_txconf::txq_flags
+ * @see rte_eth_dev_info_get, struct rte_eth_txq_conf::txq_flags
  *
  * @param port_id
  *   The port identifier of the Ethernet device.
diff --git a/test/test-pipeline/init.c b/test/test-pipeline/init.c
index 1457c7890..eee75fb0e 100644
--- a/test/test-pipeline/init.c
+++ b/test/test-pipeline/init.c
@@ -117,7 +117,7 @@ static struct rte_eth_conf port_conf = {
 	},
 };
 
-static struct rte_eth_rxconf rx_conf = {
+static struct rte_eth_rxq_conf rx_conf = {
 	.rx_thresh = {
 		.pthresh = 8,
 		.hthresh = 8,
@@ -127,7 +127,7 @@ static struct rte_eth_rxconf rx_conf = {
 	.rx_drop_en = 0,
 };
 
-static struct rte_eth_txconf tx_conf = {
+static struct rte_eth_txq_conf tx_conf = {
 	.tx_thresh = {
 		.pthresh = 36,
 		.hthresh = 0,
diff --git a/test/test/test_kni.c b/test/test/test_kni.c
index db17fdf30..b5445e167 100644
--- a/test/test/test_kni.c
+++ b/test/test/test_kni.c
@@ -67,7 +67,7 @@ struct test_kni_stats {
 	volatile uint64_t egress;
 };
 
-static const struct rte_eth_rxconf rx_conf = {
+static const struct rte_eth_rxq_conf rx_conf = {
 	.rx_thresh = {
 		.pthresh = 8,
 		.hthresh = 8,
@@ -76,7 +76,7 @@ static const struct rte_eth_rxconf rx_conf = {
 	.rx_free_thresh = 0,
 };
 
-static const struct rte_eth_txconf tx_conf = {
+static const struct rte_eth_txq_conf tx_conf = {
 	.tx_thresh = {
 		.pthresh = 36,
 		.hthresh = 0,
diff --git a/test/test/test_link_bonding.c b/test/test/test_link_bonding.c
index dc28cea59..af23b1ae1 100644
--- a/test/test/test_link_bonding.c
+++ b/test/test/test_link_bonding.c
@@ -199,7 +199,7 @@ static struct rte_eth_conf default_pmd_conf = {
 	.lpbk_mode = 0,
 };
 
-static const struct rte_eth_rxconf rx_conf_default = {
+static const struct rte_eth_rxq_conf rx_conf_default = {
 	.rx_thresh = {
 		.pthresh = RX_PTHRESH,
 		.hthresh = RX_HTHRESH,
@@ -209,7 +209,7 @@ static const struct rte_eth_rxconf rx_conf_default = {
 	.rx_drop_en = 0,
 };
 
-static struct rte_eth_txconf tx_conf_default = {
+static struct rte_eth_txq_conf tx_conf_default = {
 	.tx_thresh = {
 		.pthresh = TX_PTHRESH,
 		.hthresh = TX_HTHRESH,
diff --git a/test/test/test_pmd_perf.c b/test/test/test_pmd_perf.c
index 1ffd65a52..6f28ad303 100644
--- a/test/test/test_pmd_perf.c
+++ b/test/test/test_pmd_perf.c
@@ -109,7 +109,7 @@ static struct rte_eth_conf port_conf = {
 	.lpbk_mode = 1,  /* enable loopback */
 };
 
-static struct rte_eth_rxconf rx_conf = {
+static struct rte_eth_rxq_conf rx_conf = {
 	.rx_thresh = {
 		.pthresh = RX_PTHRESH,
 		.hthresh = RX_HTHRESH,
@@ -118,7 +118,7 @@ static struct rte_eth_rxconf rx_conf = {
 	.rx_free_thresh = 32,
 };
 
-static struct rte_eth_txconf tx_conf = {
+static struct rte_eth_txq_conf tx_conf = {
 	.tx_thresh = {
 		.pthresh = TX_PTHRESH,
 		.hthresh = TX_HTHRESH,
diff --git a/test/test/virtual_pmd.c b/test/test/virtual_pmd.c
index 9d46ad564..fb2479ced 100644
--- a/test/test/virtual_pmd.c
+++ b/test/test/virtual_pmd.c
@@ -124,7 +124,7 @@ static int
 virtual_ethdev_rx_queue_setup_success(struct rte_eth_dev *dev,
 		uint16_t rx_queue_id, uint16_t nb_rx_desc __rte_unused,
 		unsigned int socket_id,
-		const struct rte_eth_rxconf *rx_conf __rte_unused,
+		const struct rte_eth_rxq_conf *rx_conf __rte_unused,
 		struct rte_mempool *mb_pool __rte_unused)
 {
 	struct virtual_ethdev_queue *rx_q;
@@ -147,7 +147,7 @@ static int
 virtual_ethdev_rx_queue_setup_fail(struct rte_eth_dev *dev __rte_unused,
 		uint16_t rx_queue_id __rte_unused, uint16_t nb_rx_desc __rte_unused,
 		unsigned int socket_id __rte_unused,
-		const struct rte_eth_rxconf *rx_conf __rte_unused,
+		const struct rte_eth_rxq_conf *rx_conf __rte_unused,
 		struct rte_mempool *mb_pool __rte_unused)
 {
 	return -1;
@@ -157,7 +157,7 @@ static int
 virtual_ethdev_tx_queue_setup_success(struct rte_eth_dev *dev,
 		uint16_t tx_queue_id, uint16_t nb_tx_desc __rte_unused,
 		unsigned int socket_id,
-		const struct rte_eth_txconf *tx_conf __rte_unused)
+		const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct virtual_ethdev_queue *tx_q;
 
@@ -179,7 +179,7 @@ static int
 virtual_ethdev_tx_queue_setup_fail(struct rte_eth_dev *dev __rte_unused,
 		uint16_t tx_queue_id __rte_unused, uint16_t nb_tx_desc __rte_unused,
 		unsigned int socket_id __rte_unused,
-		const struct rte_eth_txconf *tx_conf __rte_unused)
+		const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	return -1;
 }

diff --git a/drivers/net/liquidio/lio_ethdev.c b/drivers/net/liquidio/lio_ethdev.c
index a17fba501..e1bbddde7 100644
--- a/drivers/net/liquidio/lio_ethdev.c
+++ b/drivers/net/liquidio/lio_ethdev.c
@@ -1150,7 +1150,7 @@ lio_dev_mq_rx_configure(struct rte_eth_dev *eth_dev)
  * @param socket_id
  *    Where to allocate memory
  * @param rx_conf
  *    Pointer to the struction rte_eth_rxconf
  * @param mp
  *    Pointer to the packet pool
  *
@@ -1161,7 +1161,7 @@ lio_dev_mq_rx_configure(struct rte_eth_dev *eth_dev)
 static int
 lio_dev_rx_queue_setup(struct rte_eth_dev *eth_dev, uint16_t q_no,
 		       uint16_t num_rx_descs, unsigned int socket_id,
-		       const struct rte_eth_rxconf *rx_conf __rte_unused,
+		       const struct rte_eth_rxq_conf *rx_conf __rte_unused,
 		       struct rte_mempool *mp)
 {
 	struct lio_device *lio_dev = LIO_DEV(eth_dev);
@@ -1242,7 +1242,7 @@ lio_dev_rx_queue_release(void *rxq)
  *   NUMA socket id, used for memory allocations
  *
  * @param tx_conf
  *   Pointer to the structure rte_eth_txconf
  *
  * @return
  *   - On success, return 0
@@ -1251,7 +1251,7 @@ lio_dev_rx_queue_release(void *rxq)
 static int
 lio_dev_tx_queue_setup(struct rte_eth_dev *eth_dev, uint16_t q_no,
 		       uint16_t num_tx_descs, unsigned int socket_id,
-		       const struct rte_eth_txconf *tx_conf __rte_unused)
+		       const struct rte_eth_txq_conf *tx_conf __rte_unused)
 {
 	struct lio_device *lio_dev = LIO_DEV(eth_dev);
 	int fw_mapped_iq = lio_dev->linfo.txpciq[q_no].s.q_no;
@@ -1150,7 +1150,7 @@ lio_dev_mq_rx_configure(struct rte_eth_dev *eth_dev)
  *    Where to allocate memory
  * @param rx_conf
- *    Pointer to the struction rte_eth_rxconf
+ *    Pointer to the struction rte_eth_rxq_conf
  * @param mp
  *    Pointer to the packet pool
@@ -1242,7 +1242,7 @@ lio_dev_rx_queue_release(void *rxq)
  *
  * @param tx_conf
- *   Pointer to the structure rte_eth_txconf
+ *   Pointer to the structure rte_eth_txq_conf
  *
  * @return
diff --git a/drivers/net/virtio/virtio_rxtx.c b/drivers/net/virtio/virtio_rxtx.c
index e30377c51..cff1d9b62 100644
--- a/drivers/net/virtio/virtio_rxtx.c
+++ b/drivers/net/virtio/virtio_rxtx.c
@@ -414,7 +414,7 @@ virtio_dev_rx_queue_setup(struct rte_eth_dev *dev,
 			uint16_t queue_idx,
 			uint16_t nb_desc,
 			unsigned int socket_id __rte_unused,
-			__rte_unused const struct rte_eth_rxconf *rx_conf,
+			__rte_unused const struct rte_eth_rxq_conf *rx_conf,
 			struct rte_mempool *mp)
 {
 	uint16_t vtpci_queue_idx = 2 * queue_idx + VTNET_SQ_RQ_QUEUE_IDX;
@@ -492,7 +492,7 @@ virtio_dev_rx_queue_setup(struct rte_eth_dev *dev,
 
 static void
 virtio_update_rxtx_handler(struct rte_eth_dev *dev,
-			   const struct rte_eth_txconf *tx_conf)
+			   const struct rte_eth_txq_conf *tx_conf)
 {
 	uint8_t use_simple_rxtx = 0;
 	struct virtio_hw *hw = dev->data->dev_private;
@@ -519,7 +519,7 @@ virtio_update_rxtx_handler(struct rte_eth_dev *dev,
  * struct rte_eth_dev *dev: Used to update dev
  * uint16_t nb_desc: Defaults to values read from config space
  * unsigned int socket_id: Used to allocate memzone
  * const struct rte_eth_txconf *tx_conf: Used to setup tx engine
  * uint16_t queue_idx: Just used as an index in dev txq list
  */
 int
@@ -527,7 +527,7 @@ virtio_dev_tx_queue_setup(struct rte_eth_dev *dev,
 			uint16_t queue_idx,
 			uint16_t nb_desc,
 			unsigned int socket_id __rte_unused,
-			const struct rte_eth_txconf *tx_conf)
+			const struct rte_eth_txq_conf *tx_conf)
 {
 	uint8_t vtpci_queue_idx = 2 * queue_idx + VTNET_SQ_TQ_QUEUE_IDX;
 	struct virtio_hw *hw = dev->data->dev_private;
@@ -519,7 +519,7 @@ virtio_update_rxtx_handler(struct rte_eth_dev *dev,
  * uint16_t nb_desc: Defaults to values read from config space
  * unsigned int socket_id: Used to allocate memzone
- * const struct rte_eth_txconf *tx_conf: Used to setup tx engine
+ * const struct rte_eth_txq_conf *tx_conf: Used to setup tx engine
  * uint16_t queue_idx: Just used as an index in dev txq list
  */